/*

 File: costlytest_ln.cpp, 2004/09/24
 Test intervals adapted to domain restrictions

 CoStLy (COmplex interval STandard functions LibrarY), Version 1.0.0

 Copyright (C) Markus Neher, markus.neher@math.uni-karlsruhe.de
               Ingo Eble,    ingoeble@web.de

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#include "cimath.h"
#include <iostream>

//  define test function f
//  typedef Interval or CInterval depending on the function type!
//  also change the output string for f and the test interval set below!
//
typedef CInterval (*f_pointer)(const CInterval&);
f_pointer my_f = CoStLy::ln;

int main()
{ 
  std::string
    f_date = "040928",
    f_string = "f(z) = ln";

  std::cout<<f_date+"  "+f_string<<std::endl<<std::endl<<std::endl;
  std::cout<<"Test intervals for the complex plane without the origin."<<std::endl<<std::endl<<std::endl;

  //  point intervals

  double eps4  = 1.0E-4;
  double eps10 = 1.0E-10;

  CInterval z01(Interval(0,0),Interval(-1,-1)); 
  CInterval z02(Interval(1,1),Interval(0,0));  
  CInterval z03(Interval(0,0),Interval(1,1));  
  CInterval z04(Interval(-1,-1),Interval(eps10,eps10));  
  CInterval z05(Interval(-1,-1),Interval(-eps10,-eps10));  
  CInterval z06(Interval(1,1),Interval(-100,-100));  
  CInterval z07(Interval(100,100),Interval(1,1)); 
  CInterval z08(Interval(-1,-1),Interval(100,100));
  CInterval z09(Interval(-10,-10),Interval(-20,-20));  
  CInterval z10(Interval(eps10,eps10),Interval(eps10,eps10));  

  CInterval res01( my_f( z01 ) );
  CInterval res02( my_f( z02 ) );
  CInterval res03( my_f( z03 ) );
  CInterval res04( my_f( z04 ) );
  CInterval res05( my_f( z05 ) );
  CInterval res06( my_f( z06 ) );
  CInterval res07( my_f( z07 ) );
  CInterval res08( my_f( z08 ) );
  CInterval res09( my_f( z09 ) );
  CInterval res10( my_f( z10 ) );

  std::cout<<f_string+": Point intervals"<<std::endl<<std::endl;

  std::cout<<"z01    = "<<z01<<std::endl<<"f(z01) = "<<res01<<std::endl;
  std::cout<<"w(f(z01)) = [ "<<sup(res01.re())-inf(res01.re())<<", "<<sup(res01.im())-inf(res01.im())<<" ]"<<std::endl<<std::endl;
  std::cout<<"z02    = "<<z02<<std::endl<<"f(z02) = "<<res02<<std::endl;
  std::cout<<"w(f(z02)) = [ "<<sup(res02.re())-inf(res02.re())<<", "<<sup(res02.im())-inf(res02.im())<<" ]"<<std::endl<<std::endl;
  std::cout<<"z03    = "<<z03<<std::endl<<"f(z03) = "<<res03<<std::endl;
  std::cout<<"w(f(z03)) = [ "<<sup(res03.re())-inf(res03.re())<<", "<<sup(res03.im())-inf(res03.im())<<" ]"<<std::endl<<std::endl;
  std::cout<<"z04    = "<<z04<<std::endl<<"f(z04) = "<<res04<<std::endl;
  std::cout<<"w(f(z04)) = [ "<<sup(res04.re())-inf(res04.re())<<", "<<sup(res04.im())-inf(res04.im())<<" ]"<<std::endl<<std::endl;
  std::cout<<"z05    = "<<z05<<std::endl<<"f(z05) = "<<res05<<std::endl;
  std::cout<<"w(f(z05)) = [ "<<sup(res05.re())-inf(res05.re())<<", "<<sup(res05.im())-inf(res05.im())<<" ]"<<std::endl<<std::endl;
  std::cout<<"z06    = "<<z06<<std::endl<<"f(z06) = "<<res06<<std::endl;
  std::cout<<"w(f(z06)) = [ "<<sup(res06.re())-inf(res06.re())<<", "<<sup(res06.im())-inf(res06.im())<<" ]"<<std::endl<<std::endl;
  std::cout<<"z07    = "<<z07<<std::endl<<"f(z07) = "<<res07<<std::endl;
  std::cout<<"w(f(z07)) = [ "<<sup(res07.re())-inf(res07.re())<<", "<<sup(res07.im())-inf(res07.im())<<" ]"<<std::endl<<std::endl;
  std::cout<<"z08    = "<<z08<<std::endl<<"f(z08) = "<<res08<<std::endl;
  std::cout<<"w(f(z08)) = [ "<<sup(res08.re())-inf(res08.re())<<", "<<sup(res08.im())-inf(res08.im())<<" ]"<<std::endl<<std::endl;
  std::cout<<"z09    = "<<z09<<std::endl<<"f(z09) = "<<res09<<std::endl;
  std::cout<<"w(f(z09)) = [ "<<sup(res09.re())-inf(res09.re())<<", "<<sup(res09.im())-inf(res09.im())<<" ]"<<std::endl<<std::endl;
  std::cout<<"z10    = "<<z10<<std::endl<<"f(z10) = "<<res10<<std::endl;
  std::cout<<"w(f(z10)) = [ "<<sup(res10.re())-inf(res10.re())<<", "<<sup(res10.im())-inf(res10.im())<<" ]"<<std::endl<<std::endl;

  //  lower half plane, left to right

  CInterval z11(Interval(-3,-1),Interval(-2,-1)); 
  CInterval z12(Interval(-1,0),Interval(-2,-eps10));  
  CInterval z13(Interval(0,3),Interval(-2,-eps10));  
  CInterval z14(Interval(-2,5),Interval(-2,-eps10));  
  CInterval z15(Interval(1,2),Interval(-7,-1));  
  CInterval z16(Interval(eps10,eps10),Interval(-2,-1)); 
  CInterval z17(Interval(-2,-1),Interval(-8,-1));  
  CInterval z18(Interval(-3,-eps10),Interval(-6,-5));  
  CInterval z19(Interval(1,8),Interval(-0.01,-0.001));  
  CInterval z20(Interval(3,3),Interval(-5,-0.001));  

  CInterval res11( my_f( z11 ) );
  CInterval res12( my_f( z12 ) );
  CInterval res13( my_f( z13 ) );
  CInterval res14( my_f( z14 ) );
  CInterval res15( my_f( z15 ) );
  CInterval res16( my_f( z16 ) );
  CInterval res17( my_f( z17 ) );
  CInterval res18( my_f( z18 ) );
  CInterval res19( my_f( z19 ) );
  CInterval res20( my_f( z20 ) );

  std::cout<<f_string+": Lower half plane, left to right"<<std::endl<<std::endl;

  std::cout<<"z11    = "<<z11<<std::endl<<"f(z11) = "<<res11<<std::endl<<std::endl;
  std::cout<<"z12    = "<<z12<<std::endl<<"f(z12) = "<<res12<<std::endl<<std::endl;
  std::cout<<"z13    = "<<z13<<std::endl<<"f(z13) = "<<res13<<std::endl<<std::endl;
  std::cout<<"z14    = "<<z14<<std::endl<<"f(z14) = "<<res14<<std::endl<<std::endl;
  std::cout<<"z15    = "<<z15<<std::endl<<"f(z15) = "<<res15<<std::endl<<std::endl;
  std::cout<<"z16    = "<<z16<<std::endl<<"f(z16) = "<<res16<<std::endl<<std::endl;
  std::cout<<"z17    = "<<z17<<std::endl<<"f(z17) = "<<res17<<std::endl<<std::endl;
  std::cout<<"z18    = "<<z18<<std::endl<<"f(z18) = "<<res18<<std::endl<<std::endl;
  std::cout<<"z19    = "<<z19<<std::endl<<"f(z19) = "<<res19<<std::endl<<std::endl;
  std::cout<<"z20    = "<<z20<<std::endl<<"f(z20) = "<<res20<<std::endl<<std::endl;

  //  right half plane, bottom to top

  CInterval z21(Interval(1,2),Interval(-123,-45)); 
  CInterval z22(Interval(3,13),Interval(-28,-eps10));
  CInterval z23(Interval(123,123),Interval(-eps10,eps10));
  CInterval z24(Interval(4,600),Interval(0,0));
  CInterval z25(Interval(1,3),Interval(0,3)); 
  CInterval z26(Interval(6,14),Interval(eps10,eps4));
  CInterval z27(Interval(eps10,eps10),Interval(0,0));
  CInterval z28(Interval(eps10,eps10),Interval(-3,2));
  CInterval z29(Interval(1,1),Interval(0,252));
  CInterval z30(Interval(1,2),Interval(36,12345678));
  
  CInterval res21( my_f( z21 ) );
  CInterval res22( my_f( z22 ) );
  CInterval res23( my_f( z23 ) );  
  CInterval res24( my_f( z24 ) );
  CInterval res25( my_f( z25 ) );
  CInterval res26( my_f( z26 ) );
  CInterval res27( my_f( z27 ) );
  CInterval res28( my_f( z28 ) );
  CInterval res29( my_f( z29 ) );
  CInterval res30( my_f( z30 ) );
  
  std::cout<<std::endl<<f_string+": Right half plane, bottom to top"<<std::endl<<std::endl;

  std::cout<<"z21    = "<<z21<<std::endl<<"f(z21) = "<<res21<<std::endl<<std::endl;
  std::cout<<"z22    = "<<z22<<std::endl<<"f(z22) = "<<res22<<std::endl<<std::endl;
  std::cout<<"z23    = "<<z23<<std::endl<<"f(z23) = "<<res23<<std::endl<<std::endl;
  std::cout<<"z24    = "<<z24<<std::endl<<"f(z24) = "<<res24<<std::endl<<std::endl;
  std::cout<<"z25    = "<<z25<<std::endl<<"f(z25) = "<<res25<<std::endl<<std::endl;
  std::cout<<"z26    = "<<z26<<std::endl<<"f(z26) = "<<res26<<std::endl<<std::endl;
  std::cout<<"z27    = "<<z27<<std::endl<<"f(z27) = "<<res27<<std::endl<<std::endl;
  std::cout<<"z28    = "<<z28<<std::endl<<"f(z28) = "<<res28<<std::endl<<std::endl;
  std::cout<<"z29    = "<<z29<<std::endl<<"f(z29) = "<<res29<<std::endl<<std::endl;
  std::cout<<"z30    = "<<z30<<std::endl<<"f(z30) = "<<res30<<std::endl<<std::endl;
  
  //  upper half plane, right to left

  CInterval z31(Interval(1,2),Interval(1,2));  
  CInterval z32(Interval(eps10,1),Interval(1,2));  
  CInterval z33(Interval(-1,1),Interval(1+eps10,1+eps10));  
  CInterval z34(Interval(-1,-eps10),Interval(1,1));  
  CInterval z35(Interval(-2,-1),Interval(1,2)); 
  CInterval z36(Interval(3,3),Interval(0.001,5));  
  CInterval z37(Interval(1,8),Interval(0.001,0.01));  
  CInterval z38(Interval(-4,8),Interval(eps10,1.6));  
  CInterval z39(Interval(-2,-1),Interval(1,8));  
  CInterval z40(Interval(-8,-1),Interval(1,2)); 

  CInterval res31( my_f( z31 ) );
  CInterval res32( my_f( z32 ) );
  CInterval res33( my_f( z33 ) );
  CInterval res34( my_f( z34 ) );
  CInterval res35( my_f( z35 ) );
  CInterval res36( my_f( z36 ) );
  CInterval res37( my_f( z37 ) );
  CInterval res38( my_f( z38 ) );
  CInterval res39( my_f( z39 ) );
  CInterval res40( my_f( z40 ) );

  std::cout<<std::endl<<f_string+": Upper half plane, right to left"<<std::endl<<std::endl;

  std::cout<<"z31    = "<<z31<<std::endl<<"f(z31) = "<<res31<<std::endl<<std::endl;
  std::cout<<"z32    = "<<z32<<std::endl<<"f(z32) = "<<res32<<std::endl<<std::endl;
  std::cout<<"z33    = "<<z33<<std::endl<<"f(z33) = "<<res33<<std::endl<<std::endl;
  std::cout<<"z34    = "<<z34<<std::endl<<"f(z34) = "<<res34<<std::endl<<std::endl;
  std::cout<<"z35    = "<<z35<<std::endl<<"f(z35) = "<<res35<<std::endl<<std::endl;
  std::cout<<"z36    = "<<z36<<std::endl<<"f(z36) = "<<res36<<std::endl<<std::endl;
  std::cout<<"z37    = "<<z37<<std::endl<<"f(z37) = "<<res37<<std::endl<<std::endl;
  std::cout<<"z38    = "<<z38<<std::endl<<"f(z38) = "<<res38<<std::endl<<std::endl;
  std::cout<<"z39    = "<<z39<<std::endl<<"f(z39) = "<<res39<<std::endl<<std::endl;
  std::cout<<"z40    = "<<z40<<std::endl<<"f(z40) = "<<res40<<std::endl<<std::endl;

  //  intervals near the origin, bottom to top
  //  program crashes if any of the following function calls is irregular

  CInterval z41(Interval(eps10,eps10),Interval(-2,0)); 
  CInterval z42(Interval(eps10,eps10),Interval(-123,145)); 
  CInterval z43(Interval(-123,1234),Interval(eps10,eps10)); 
  CInterval z44(Interval(eps10,eps10),Interval(eps10,eps10)); 
  CInterval z45(Interval(eps10,1),Interval(-1,-eps10)); 
  CInterval z46(Interval(-1,-eps10),Interval(-1,-eps10)); 
  CInterval z47(Interval(eps10,1),Interval(0.1E-10,0.1E-10)); 
  CInterval z48(Interval(-0.1,-eps10),Interval(0.1,0.2)); 
  CInterval z49(Interval(-3,8),Interval(1.1,4)); 
  CInterval z50(Interval(-7,199),Interval(-eps10,-eps10)); 

  CInterval res41( my_f( z41 ) );
  CInterval res42( my_f( z42 ) );
  CInterval res43( my_f( z43 ) );
  CInterval res44( my_f( z44 ) );
  CInterval res45( my_f( z45 ) );
  CInterval res46( my_f( z46 ) );
  CInterval res47( my_f( z47 ) );
  CInterval res48( my_f( z48 ) );
  CInterval res49( my_f( z49 ) );
  CInterval res50( my_f( z50 ) );

  std::cout<<std::endl<<f_string+": Intervals near the origin, bottom to top"<<std::endl<<std::endl;
  
  std::cout<<"z41    = "<<z41<<std::endl<<"f(z41) = "<<res41<<std::endl<<std::endl;
  std::cout<<"z42    = "<<z42<<std::endl<<"f(z42) = "<<res42<<std::endl<<std::endl;
  std::cout<<"z43    = "<<z43<<std::endl<<"f(z43) = "<<res43<<std::endl<<std::endl;
  std::cout<<"z44    = "<<z44<<std::endl<<"f(z44) = "<<res44<<std::endl<<std::endl;
  std::cout<<"z45    = "<<z45<<std::endl<<"f(z45) = "<<res45<<std::endl<<std::endl;
  std::cout<<"z46    = "<<z46<<std::endl<<"f(z46) = "<<res46<<std::endl<<std::endl;
  std::cout<<"z47    = "<<z47<<std::endl<<"f(z47) = "<<res47<<std::endl<<std::endl;
  std::cout<<"z48    = "<<z48<<std::endl<<"f(z48) = "<<res48<<std::endl<<std::endl;
  std::cout<<"z49    = "<<z49<<std::endl<<"f(z49) = "<<res49<<std::endl<<std::endl;
  std::cout<<"z50    = "<<z50<<std::endl<<"f(z50) = "<<res50<<std::endl<<std::endl;

  //  intervals containing negative reals, left to right, top to bottom
  //  program crashes if any of the following function calls is irregular

  CInterval z51(Interval(-2,-1),Interval(1,41)); 
  CInterval z52(Interval(-2,-1),Interval(0,21)); 
  CInterval z53(Interval(-52,-1),Interval(0,0)); 
  CInterval z54(Interval(-52,18),Interval(-1,-eps10)); 
  CInterval z55(Interval(-11,-7),Interval(-20,-eps10));  
  CInterval z56(Interval(-5.001,-5),Interval(-21,-2.2));  
  CInterval z57(Interval(-1.0E-10,-1.0E-10),Interval(-eps10,eps10));  
  CInterval z58(Interval(-100,-100),Interval(0,0));  
  CInterval z59(Interval(-11,-7),Interval(-1.0E-10,1.0E-10));  
  CInterval z60(Interval(-11,-7),Interval(0,0));  
  
  CInterval res51( my_f( z51 ) );
  CInterval res52( my_f( z52 ) );
  CInterval res53( my_f( z53 ) );
  CInterval res54( my_f( z54 ) );
  CInterval res55( my_f( z55 ) );
  CInterval res56( my_f( z56 ) );
  CInterval res57( my_f( z57 ) );
  CInterval res58( my_f( z58 ) );
  CInterval res59( my_f( z59 ) );
  CInterval res60( my_f( z60 ) );
  
  std::cout<<std::endl<<f_string+": Intervals containing negative reals, l to r, t to b"<<std::endl<<std::endl;
  
  std::cout<<"z51    = "<<z51<<std::endl<<"f(z51) = "<<res51<<std::endl<<std::endl;
  std::cout<<"z52    = "<<z52<<std::endl<<"f(z52) = "<<res52<<std::endl<<std::endl;
  std::cout<<"z53    = "<<z53<<std::endl<<"f(z53) = "<<res53<<std::endl<<std::endl;
  std::cout<<"z54    = "<<z54<<std::endl<<"f(z54) = "<<res54<<std::endl<<std::endl;
  std::cout<<"z55    = "<<z55<<std::endl<<"f(z55) = "<<res55<<std::endl<<std::endl;
  std::cout<<"z56    = "<<z56<<std::endl<<"f(z56) = "<<res56<<std::endl<<std::endl;
  std::cout<<"z57    = "<<z57<<std::endl<<"f(z57) = "<<res57<<std::endl<<std::endl;
  std::cout<<"z58    = "<<z58<<std::endl<<"f(z58) = "<<res58<<std::endl<<std::endl;
  std::cout<<"z59    = "<<z59<<std::endl<<"f(z59) = "<<res59<<std::endl<<std::endl;
  std::cout<<"z60    = "<<z60<<std::endl<<"f(z60) = "<<res60<<std::endl<<std::endl;

  //  intervals near negative real axes, top to bottom
  //  program crashes if any of the following function calls is irregular
     
  CInterval z61(Interval(-11,-10),Interval(456,789)); 
  CInterval z62(Interval(-123,-1),Interval(1,41)); 
  CInterval z63(Interval(-1,-1),Interval(1,41)); 
  CInterval z64(Interval(-1,-eps10),Interval(1,41)); 
  CInterval z65(Interval(-1,-eps10),Interval(eps10,1)); 
  CInterval z66(Interval(-1,-eps10),Interval(-eps10,-eps10)); 
  CInterval z67(Interval(-1,0),Interval(-eps10,-eps10)); 
  CInterval z68(Interval(-11,-7),Interval(-1,-eps10));
  CInterval z69(Interval(-52,-51),Interval(-8,-0.3)); 
  CInterval z70(Interval(-1122,-767),Interval(-0.851,-0.518)); 
  
  CInterval res61( my_f( z61 ) );
  CInterval res62( my_f( z62 ) );
  CInterval res63( my_f( z63 ) );
  CInterval res64( my_f( z64 ) );
  CInterval res65( my_f( z65 ) );
  CInterval res66( my_f( z66 ) );
  CInterval res67( my_f( z67 ) );
  CInterval res68( my_f( z68 ) );
  CInterval res69( my_f( z69 ) );
  CInterval res70( my_f( z70 ) );
      
  std::cout<<std::endl<<f_string+": Intervals near negative real axes, t to b"<<std::endl<<std::endl;

  std::cout<<"z61    = "<<z61<<std::endl<<"f(z61) = "<<res61<<std::endl<<std::endl;
  std::cout<<"z62    = "<<z62<<std::endl<<"f(z62) = "<<res62<<std::endl<<std::endl;
  std::cout<<"z63    = "<<z63<<std::endl<<"f(z63) = "<<res63<<std::endl<<std::endl;
  std::cout<<"z64    = "<<z64<<std::endl<<"f(z64) = "<<res64<<std::endl<<std::endl;
  std::cout<<"z65    = "<<z65<<std::endl<<"f(z65) = "<<res65<<std::endl<<std::endl;
  std::cout<<"z66    = "<<z66<<std::endl<<"f(z66) = "<<res66<<std::endl<<std::endl;
  std::cout<<"z67    = "<<z67<<std::endl<<"f(z67) = "<<res67<<std::endl<<std::endl;
  std::cout<<"z68    = "<<z68<<std::endl<<"f(z68) = "<<res68<<std::endl<<std::endl;
  std::cout<<"z69    = "<<z69<<std::endl<<"f(z69) = "<<res69<<std::endl<<std::endl;
  std::cout<<"z70    = "<<z70<<std::endl<<"f(z70) = "<<res70<<std::endl<<std::endl;
  
  CInterval z71(Interval(-2,2),Interval(eps10,eps10)); 
  CInterval z72(Interval(-3,3),Interval(-eps10,-eps10)); 
  CInterval z73(Interval(eps10,eps10),Interval(-1,10)); 
  CInterval z74(Interval(-6,-5),Interval(eps10,eps10));
  CInterval z75(Interval(-6,-5),Interval(-eps10,-eps10));
  CInterval z76(Interval(-6,-5),Interval(eps10,1));
  CInterval z77(Interval(-6,-5),Interval(-1,-eps10));
  CInterval z78(Interval(-666,-555),Interval(eps10,666));    
  CInterval z79(Interval(-666,-555),Interval(-555,-eps10)); 
  CInterval z80(Interval(-11,10),Interval(-31,-eps10)); 
  
  CInterval res71( my_f( z71 ) );
  CInterval res72( my_f( z72 ) );
  CInterval res73( my_f( z73 ) );
  CInterval res74( my_f( z74 ) );
  CInterval res75( my_f( z75 ) );
  CInterval res76( my_f( z76 ) );
  CInterval res77( my_f( z77 ) );
  CInterval res78( my_f( z78 ) );
  CInterval res79( my_f( z79 ) );
  CInterval res80( my_f( z80 ) );
  
  std::cout<<"z71    = "<<z71<<std::endl<<"f(z71) = "<<res71<<std::endl<<std::endl;
  std::cout<<"z72    = "<<z72<<std::endl<<"f(z72) = "<<res72<<std::endl<<std::endl;
  std::cout<<"z73    = "<<z73<<std::endl<<"f(z73) = "<<res73<<std::endl<<std::endl;
  std::cout<<"z74    = "<<z74<<std::endl<<"f(z74) = "<<res74<<std::endl<<std::endl;
  std::cout<<"z75    = "<<z75<<std::endl<<"f(z75) = "<<res75<<std::endl<<std::endl;
  std::cout<<"z76    = "<<z76<<std::endl<<"f(z76) = "<<res76<<std::endl<<std::endl;
  std::cout<<"z77    = "<<z77<<std::endl<<"f(z77) = "<<res77<<std::endl<<std::endl;
  std::cout<<"z78    = "<<z78<<std::endl<<"f(z78) = "<<res78<<std::endl<<std::endl;
  std::cout<<"z79    = "<<z79<<std::endl<<"f(z79) = "<<res79<<std::endl<<std::endl;
  std::cout<<"z80    = "<<z80<<std::endl<<"f(z80) = "<<res80<<std::endl<<std::endl; 

     
  //  intervals near +-1

  CInterval z81(Interval(-1,-1),Interval(eps10,eps10));  
  CInterval z82(Interval(-1,-1),Interval(eps10,eps10));  
  CInterval z83(Interval(1,1),Interval(eps10,eps10));  
  CInterval z84(Interval(1,1),Interval(eps10,eps10));  
  CInterval z85(Interval(2,11),Interval(eps10,eps10));  
  CInterval z86(Interval(-12,-1),Interval(eps10,eps10));  
  CInterval z87(Interval(-1,1),Interval(-35,-10.95));  
  CInterval z88(Interval(-1,-1),Interval(1.0E-10,5));  
  CInterval z89(Interval(-1,-1),Interval(-7,-1.0E-10));  
  CInterval z90(Interval(1+eps10,1+eps10),Interval(-7,11));  

  CInterval z91(Interval(-2,-1),Interval(eps10,eps10));  
  CInterval z92(Interval(-2,0),Interval(1+eps10,1+eps10));  
  CInterval z93(Interval(-2,1),Interval(-1-eps10,-1-eps10));  
  CInterval z94(Interval(-2,12345),Interval(4,12345));  
  CInterval z95(Interval(1,2),Interval(eps10,eps10));  
  CInterval z96(Interval(-2,-1),Interval(eps10,eps10));  
  CInterval z97(Interval(-2,0),Interval(-1-eps10,-1-eps10));  
  CInterval z98(Interval(-2,-eps10),Interval(eps10,eps10));  
  CInterval z99(Interval(-2,2),Interval(1+eps10,1+eps10));  
  CInterval z100(Interval(1,2),Interval(eps10,eps10));  

  CInterval res81( my_f( z81 ) );
  CInterval res82( my_f( z82 ) );
  CInterval res83( my_f( z83 ) );
  CInterval res84( my_f( z84 ) );
  CInterval res85( my_f( z85 ) );
  CInterval res86( my_f( z86 ) );
  CInterval res87( my_f( z87 ) );
  CInterval res88( my_f( z88 ) );
  CInterval res89( my_f( z89 ) );
  CInterval res90( my_f( z90 ) );

  CInterval res91( my_f( z91 ) );
  CInterval res92( my_f( z92 ) );
  CInterval res93( my_f( z93 ) );
  CInterval res94( my_f( z94 ) );
  CInterval res95( my_f( z95 ) );
  CInterval res96( my_f( z96 ) );
  CInterval res97( my_f( z97 ) );
  CInterval res98( my_f( z98 ) );
  CInterval res99( my_f( z99 ) );
  CInterval res100( my_f( z100 ) );

  std::cout<<std::endl<<f_string+": Intervals near +-1"<<std::endl<<std::endl;

  std::cout<<"z81    = "<<z81<<std::endl<<"f(z81) = "<<res81<<std::endl<<std::endl;
  std::cout<<"z82    = "<<z82<<std::endl<<"f(z82) = "<<res82<<std::endl<<std::endl;
  std::cout<<"z83    = "<<z83<<std::endl<<"f(z83) = "<<res83<<std::endl<<std::endl;
  std::cout<<"z84    = "<<z84<<std::endl<<"f(z84) = "<<res84<<std::endl<<std::endl;
  std::cout<<"z85    = "<<z85<<std::endl<<"f(z85) = "<<res85<<std::endl<<std::endl;
  std::cout<<"z86    = "<<z86<<std::endl<<"f(z86) = "<<res86<<std::endl<<std::endl;
  std::cout<<"z87    = "<<z87<<std::endl<<"f(z87) = "<<res87<<std::endl<<std::endl;
  std::cout<<"z88    = "<<z88<<std::endl<<"f(z88) = "<<res88<<std::endl<<std::endl;
  std::cout<<"z89    = "<<z89<<std::endl<<"f(z89) = "<<res89<<std::endl<<std::endl;
  std::cout<<"z90    = "<<z90<<std::endl<<"f(z90) = "<<res90<<std::endl<<std::endl;

  std::cout<<"z91    = "<<z91<<std::endl<<"f(z91) = "<<res91<<std::endl<<std::endl;
  std::cout<<"z92    = "<<z92<<std::endl<<"f(z92) = "<<res92<<std::endl<<std::endl;
  std::cout<<"z93    = "<<z93<<std::endl<<"f(z93) = "<<res93<<std::endl<<std::endl;
  std::cout<<"z94    = "<<z94<<std::endl<<"f(z94) = "<<res94<<std::endl<<std::endl;
  std::cout<<"z95    = "<<z95<<std::endl<<"f(z95) = "<<res95<<std::endl<<std::endl;
  std::cout<<"z96    = "<<z96<<std::endl<<"f(z96) = "<<res96<<std::endl<<std::endl;
  std::cout<<"z97    = "<<z97<<std::endl<<"f(z97) = "<<res97<<std::endl<<std::endl;
  std::cout<<"z98    = "<<z98<<std::endl<<"f(z98) = "<<res98<<std::endl<<std::endl;
  std::cout<<"z99    = "<<z99<<std::endl<<"f(z99) = "<<res99<<std::endl<<std::endl;
  std::cout<<"z100    = "<<z100<<std::endl<<"f(z100) = "<<res100<<std::endl<<std::endl;

  std::cout<<std::endl<<f_date+"  Results for "+f_string<<std::endl;

  return 0;
}



