/*

 File: analyticcontrol.h, 2004/06/16

 ACETAF, Version 3.0.0

 Copyright (C) Markus Neher, markus.neher@math.uni-karlsruhe.de
               Ingo Eble,    ingoeble@web.de

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#ifndef _ANALYTIC_CONTROL_H_INCLUDED
#define _ANALYTIC_CONTROL_H_INCLUDED

#include <qthread.h>
#include <qobject.h>

#include <string>
#include <list>

#include "circle.h"
#include "mathexpr.h"
#include "functions.h"
#include "cimath.h"


class APair
{
  std::string function;
  Circle domain;

 public:

  APair() {}
  APair(const std::string& f, const Circle& c) : function( f ), domain( c ) {}
  APair(const APair& ap) : function( ap.function ), domain( ap.domain ) {}
  ~APair() {}

  APair& operator = (const APair& ap)
  {
    function = ap.function;
    domain   = ap.domain;

    return *this;
  }

  const std::string& getFunction() const { return function; }
  const Circle& getDomain() const { return domain; }

  void setDomain(const Circle& c) { domain = c; }
};

bool operator <  (const APair&,const APair&);
bool operator <= (const APair&,const APair&);
bool operator == (const APair&,const APair&);

class ACheckControl;

class AHistory
{
  friend class ACheckControl;

  std::list<APair> history;

  void add(const APair& ap);
  
 public:

  AHistory() : history(0) {}
  ~AHistory() {}
  
  bool contain(const APair&) const;
};

class ACheck : public QThread
{
 private:

  MathExpr<CInterval> cifunction;

  APair *res;
  bool   stopThread;

  bool isRare(const CInterval&);
  bool isRare_in(const CInterval&,const Complex&,double&);
  CInterval enclosure(const Circle&);
    
 public:
  
  ACheck() : res(0) {}
  ACheck(APair* ap) : cifunction( ap->getFunction(), "z" ), res( ap ), stopThread( false ) {}
  ~ACheck() {}

  void stop();
  bool stopped();

 protected:

  void run();
};

class ACheckControl : public QObject
{
  Q_OBJECT

 public:
  
  ACheckControl() : history(0), check(0), ap(0) {}
  ACheckControl(AHistory*,const Circle&,const std::string&);
  ~ACheckControl();

  void start();
  void stop();

 protected:

  void timerEvent(QTimerEvent*);

 signals:

  void checkFinished(const APair*);
  void checkStopped();

 private:

  AHistory *history;
  ACheck   *check;
  APair    *ap;
};

#endif

/*

  End of File: analyticcontrol.h

*/
