/*

 File: gui_garbagewindow.cpp, 2003/06/17

 ACETAF, Version 3.0.0

 Copyright (C) Markus Neher, markus.neher@math.uni-karlsruhe.de
               Ingo Eble,    ingoeble@web.de

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#include "gui_garbagewindow.h"

#include <qmultilinedit.h>
#include <qpopupmenu.h>
#include <qmenubar.h>
#include <qfiledialog.h>
#include <qfile.h>
#include <qapplication.h>
#include <qregexp.h> 
#include <qstatusbar.h>
#include <qtextstream.h>

extern const QString fileIndicator;
extern const QString fileMask;

GarbageWindow::GarbageWindow(QWidget *parent, const char* name) : QMainWindow(parent, name)
{
  filename = name;
  filename += "_garbage";

  this->setCaption( filename + fileIndicator );

  //Create Menubar
  file = new QPopupMenu();
  menuBar()->insertItem( "&File", file );

  file->insertItem( "Save", this, SLOT(saveFile()));
  file->insertItem( "Save As", this, SLOT(saveFileAs()));
  file->insertSeparator();
  file->insertItem( "Close", this, SLOT(closeFile()));

  //Create Mainwindow
  edit = new QMultiLineEdit( this, "output");

  edit->setMinimumSize(200, 100);
  edit->setReadOnly( true );
  QFont font( "Courier", 14 );
  font.setFixedPitch( true );
  edit->setFont( font );

  //Set Mainwindow
  this->setCentralWidget( edit );
}

GarbageWindow::~GarbageWindow()
{
}

void GarbageWindow::saveFileAs()
{
  QFileDialog fileDialog( this );
  QString fn( fileDialog.getSaveFileName(0, fileMask, this) );
  if ( !fn.isEmpty() ) 
    {
      QString regExpStr( "\\" + fileIndicator );
      fn.replace( QRegExp( regExpStr ), "" ); 
      filename = fn;
      this->saveFile();
    } 
  else statusBar()->message("Data not saved", 2000);
}

void GarbageWindow::saveFile()
{
  QFile file( filename + fileIndicator );
  if ( !file.open( IO_WriteOnly ) )
    {
      statusBar()->message("Cannot write file", 2000);
      return;
    }
  
  QTextStream out( &file );
  out << (edit->text());

  file.close();

  setCaption( filename + fileIndicator );
  statusBar()->message( "Saved file " + filename + fileIndicator, 2000 );
}

void GarbageWindow::closeFile()
{
  this->close();
}

void GarbageWindow::getGarbage(const QString& text)
{
  edit->setAutoUpdate( false );
  edit->append( text );
  edit->setAutoUpdate( true );
  edit->setCursorPosition ( edit->numLines(), 1);
  edit->repaint();
}

void GarbageWindow::setGarbage(const QString& text)
{
  edit->setAutoUpdate( false );
  edit->append( text );
  edit->setAutoUpdate( true );
  edit->setCursorPosition ( edit->numLines(), 1);
  edit->repaint();
}

#include "gui_garbagewindow.moc"

/*

  End of File: gui_garbagewindow.cpp

*/

	  
	    



