/*

 File: gui_inputwidget.cpp, 2004/07/30

 ACETAF, Version 3.0.0

 Copyright (C) Markus Neher, markus.neher@math.uni-karlsruhe.de
               Ingo Eble,    ingoeble@web.de

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#include "gui_inputwidget.h"

#include <qcheckbox.h>
#include <qgroupbox.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qvariant.h>
#include <qtooltip.h>
#include <qwhatsthis.h>

extern const QString descriptionText;
extern const QString defaultValues[36];
 
/* 
 *  Constructs a InputWidget which is a child of 'parent', with the 
 *  name 'name' and widget flags set to 'fl' 
 */

InputWidget::InputWidget( QWidget* parent,  const char* name, WFlags fl )
    : QWidget( parent, name, fl )
{
    if ( !name )
	setName( "InputWidget" );

    InputWidgetLayout = new QVBoxLayout( this ); 
    InputWidgetLayout->setSpacing( 6 );
    InputWidgetLayout->setMargin( 11 );

    Layout13 = new QGridLayout; 
    Layout13->setSpacing( 6 );
    Layout13->setMargin( 0 );

    ExprBox = new QGroupBox( this, "ExprBox" );
    QFont ExprBox_font(  ExprBox->font() );
    ExprBox_font.setFamily( "adobe-helvetica" );
    ExprBox_font.setPointSize( 12 );
    ExprBox->setFont( ExprBox_font ); 
    ExprBox->setTitle( "Expression" );
    ExprBox->setColumnLayout(0, Qt::Vertical );
    ExprBox->layout()->setSpacing( 0 );
    ExprBox->layout()->setMargin( 0 );
    ExprBoxLayout = new QHBoxLayout( ExprBox->layout() );
    ExprBoxLayout->setAlignment( Qt::AlignTop );
    ExprBoxLayout->setSpacing( 6 );
    ExprBoxLayout->setMargin( 11 );

    ExprLabel = new QLabel( ExprBox, "ExprLabel" );
    QFont ExprLabel_font(  ExprLabel->font() );
    ExprLabel_font.setPointSize( 11 );
    ExprLabel->setFont( ExprLabel_font ); 
    ExprLabel->setText( "f(z) =" );
    ExprBoxLayout->addWidget( ExprLabel );

    data[ ExprEdit ] = new QLineEdit( ExprBox, "ExprEdit" );
    QFont ExprEdit_font(  data[ ExprEdit ]->font() );
    ExprEdit_font.setPointSize( 11 );
    data[ ExprEdit ]->setFont( ExprEdit_font ); 
    data[ ExprEdit ]->setText( defaultValues[ ExprEdit] );
    ExprBoxLayout->addWidget( data[ ExprEdit ] );

    QToolTip::add( data[ ExprEdit ], descriptionText ); 
  

    Layout13->addWidget( ExprBox, 0, 0 );

    //
    //Method Box
    //
    MethodsBox = new QGroupBox( this, "MethodsBox" );
    QFont MethodsBox_font(  MethodsBox->font() );
    MethodsBox_font.setFamily( "adobe-helvetica" );
    MethodsBox_font.setPointSize( 12 );
    MethodsBox->setFont( MethodsBox_font ); 
    MethodsBox->setTitle( "Methods for the calculation" );
    MethodsBox->setColumnLayout(0, Qt::Vertical );
    MethodsBox->layout()->setSpacing( 0 );
    MethodsBox->layout()->setMargin( 0 );

    MethodsBoxLayout = new QGridLayout( MethodsBox->layout() );
    MethodsBoxLayout->setAlignment( Qt::AlignTop );
    MethodsBoxLayout->setSpacing( 6 );
    MethodsBoxLayout->setMargin( 11 );

    Method1_CheckBox = new QCheckBox( MethodsBox, "Method1_CheckBox" );
    QFont Method1_CheckBox_font(  Method1_CheckBox->font() );
    Method1_CheckBox_font.setPointSize( 11 );
    Method1_CheckBox->setFont( Method1_CheckBox_font ); 
    Method1_CheckBox->setText( "Method I" );
    Method1_CheckBox->setChecked( true );
    QToolTip::add( Method1_CheckBox, "Cauchy's estimate" ); 

    M1 = Method1_CheckBox->isChecked();

    MethodsBoxLayout->addWidget( Method1_CheckBox, 0, 1 );

    connect(Method1_CheckBox,SIGNAL(toggled(bool)),SLOT(CheckBoxToggled()));


    Method2_CheckBox = new QCheckBox( MethodsBox, "Method2_CheckBox" );
    QFont Method2_CheckBox_font(  Method2_CheckBox->font() );
    Method2_CheckBox_font.setPointSize( 11 );
    Method2_CheckBox->setFont( Method2_CheckBox_font ); 
    Method2_CheckBox->setText( "Method II" );
    Method2_CheckBox->setChecked( true );
    QToolTip::add( Method2_CheckBox, "Cauchy's estimate with Taylor polynomial approximation" ); 

    M2 = Method2_CheckBox->isChecked();

    MethodsBoxLayout->addWidget( Method2_CheckBox, 1, 1 );

    connect(Method2_CheckBox,SIGNAL(toggled(bool)),SLOT(CheckBoxToggled()));


    Method3_CheckBox = new QCheckBox( MethodsBox, "Method3_CheckBox" );
    QFont Method3_CheckBox_font(  Method3_CheckBox->font() );
    Method3_CheckBox_font.setPointSize( 11 );
    Method3_CheckBox->setFont( Method3_CheckBox_font ); 
    Method3_CheckBox->setText( "Method III" );
    Method3_CheckBox->setChecked( true );
    QToolTip::add( Method3_CheckBox, "Cauchy's estimate for derivative" ); 

    M3 = Method3_CheckBox->isChecked();

    MethodsBoxLayout->addWidget( Method3_CheckBox, 0, 3 );

    connect(Method3_CheckBox,SIGNAL(toggled(bool)),SLOT(CheckBoxToggled()));


    Method4_CheckBox = new QCheckBox( MethodsBox, "Method4_CheckBox" );
    QFont Method4_CheckBox_font(  Method4_CheckBox->font() );
    Method4_CheckBox_font.setPointSize( 11 );
    Method4_CheckBox->setFont( Method4_CheckBox_font ); 
    Method4_CheckBox->setText( "Method IV" );
    Method4_CheckBox->setChecked( false );
    QToolTip::add( Method4_CheckBox, "Cauchy's estimate for derivative\nwith Taylor polynomial approximation" ); 

    M4 = Method4_CheckBox->isChecked();

    MethodsBoxLayout->addWidget( Method4_CheckBox, 1, 3 );

    connect(Method4_CheckBox,SIGNAL(toggled(bool)),SLOT(CheckBoxToggled()));


    Verbose_CheckBox = new QCheckBox( MethodsBox, "Verbose_CheckBox" );
    QFont Verbose_CheckBox_font(  Verbose_CheckBox->font() );
    Verbose_CheckBox_font.setPointSize( 11 );
    Verbose_CheckBox->setFont( Verbose_CheckBox_font ); 
    Verbose_CheckBox->setText( "Verbose" );
    Verbose_CheckBox->setChecked( true );

    verbose = Verbose_CheckBox->isChecked();

    MethodsBoxLayout->addMultiCellWidget( Verbose_CheckBox, 3, 3, 1, 2 );

    connect(Verbose_CheckBox,SIGNAL(toggled(bool)),SLOT(CheckBoxToggled()));

    QSpacerItem* spacer_1 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    MethodsBoxLayout->addItem( spacer_1, 0, 2 );
    QSpacerItem* spacer_2 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    MethodsBoxLayout->addItem( spacer_2, 1, 2 );
    QSpacerItem* spacer_3 = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
    MethodsBoxLayout->addItem( spacer_3, 2, 1 );
    QSpacerItem* spacer_4 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    MethodsBoxLayout->addItem( spacer_4, 0, 0 );
    QSpacerItem* spacer_5 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    MethodsBoxLayout->addItem( spacer_5, 1, 0 );
    QSpacerItem* spacer_6 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    MethodsBoxLayout->addItem( spacer_6, 3, 0 );
    QSpacerItem* spacer_7 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    MethodsBoxLayout->addItem( spacer_7, 0, 4 );
    QSpacerItem* spacer_8 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    MethodsBoxLayout->addItem( spacer_8, 1, 4 );

    Layout13->addMultiCellWidget( MethodsBox, 0, 1, 1, 1 );

    //
    //Domain Box
    //
    DomainBox = new QGroupBox( this, "DomainBox" );
    QFont DomainBox_font(  DomainBox->font() );
    DomainBox_font.setFamily( "adobe-helvetica" );
    DomainBox_font.setPointSize( 12 );
    DomainBox->setFont( DomainBox_font ); 
    DomainBox->setTitle( "Domain" );
    DomainBox->setColumnLayout(0, Qt::Vertical );
    DomainBox->layout()->setSpacing( 0 );
    DomainBox->layout()->setMargin( 0 );

    DomainBoxLayout = new QHBoxLayout( DomainBox->layout() );
    DomainBoxLayout->setAlignment( Qt::AlignTop );
    DomainBoxLayout->setSpacing( 6 );
    DomainBoxLayout->setMargin( 11 );

    CenterLabel = new QLabel( DomainBox, "CenterLabel" );
    QFont CenterLabel_font(  CenterLabel->font() );
    CenterLabel_font.setPointSize( 11 );
    CenterLabel->setFont( CenterLabel_font ); 
    CenterLabel->setText( "Center:" );
    DomainBoxLayout->addWidget( CenterLabel );

    data[ CenterEdit ] = new QLineEdit( DomainBox, "CenterEdit" );
    QFont CenterEdit_font(  data[ CenterEdit ]->font() );
    CenterEdit_font.setPointSize( 11 );
    data[ CenterEdit ]->setFont( CenterEdit_font ); 
    data[ CenterEdit ]->setText( defaultValues[ CenterEdit ] ); 

    QToolTip::add( data[ CenterEdit ], "Complex center: Re,Im" ); 

    DomainBoxLayout->addWidget( data[ CenterEdit ] );

    QSpacerItem* spacer_9 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    DomainBoxLayout->addItem( spacer_9 );

    RadiusLabel = new QLabel( DomainBox, "RadiusLabel" );
    QFont RadiusLabel_font(  RadiusLabel->font() );
    RadiusLabel_font.setPointSize( 11 );
    RadiusLabel->setFont( RadiusLabel_font ); 
    RadiusLabel->setText( "Radius:" );
    DomainBoxLayout->addWidget( RadiusLabel );

    data[ RadiusEdit ] = new QLineEdit( DomainBox, "RadiusEdit" );
    QFont RadiusEdit_font(  data[ RadiusEdit ]->font() );
    RadiusEdit_font.setPointSize( 11 );
    data[ RadiusEdit ]->setFont( RadiusEdit_font ); 
    data[ RadiusEdit ]->setText( defaultValues[ RadiusEdit ] ); 
    DomainBoxLayout->addWidget( data[ RadiusEdit ] );

    Layout13->addWidget( DomainBox, 1, 0 );
    InputWidgetLayout->addLayout( Layout13 );

    //
    //DataForMethods Box
    //
    DataForMethodsBox = new QGroupBox( this, "DataForMethodsBox" );
    QFont DataForMethodsBox_font(  DataForMethodsBox->font() );
    DataForMethodsBox_font.setFamily( "adobe-helvetica" );
    DataForMethodsBox_font.setPointSize( 12 );
    DataForMethodsBox->setFont( DataForMethodsBox_font ); 
    DataForMethodsBox->setTitle( "Parameters for the calculation" );
    DataForMethodsBox->setColumnLayout(0, Qt::Vertical );
    DataForMethodsBox->layout()->setSpacing( 0 );
    DataForMethodsBox->layout()->setMargin( 0 );
    DataForMethodsBoxLayout = new QGridLayout( DataForMethodsBox->layout() );
    DataForMethodsBoxLayout->setAlignment( Qt::AlignTop );
    DataForMethodsBoxLayout->setSpacing( 6 );
    DataForMethodsBoxLayout->setMargin( 11 );

    FixedSubdivCheckBox = new QCheckBox( DataForMethodsBox, "FixedSubdivCheckBox" );
    QFont FixedSubdivCheckBox_font(  FixedSubdivCheckBox->font() );
    FixedSubdivCheckBox_font.setPointSize( 11 );
    FixedSubdivCheckBox->setFont( FixedSubdivCheckBox_font ); 
    FixedSubdivCheckBox->setText( "Fixed grid:" );
    FixedSubdivCheckBox->setChecked( true );
    FixedSubdivCheckBox->setEnabled( M2 || M4 );
    QToolTip::add( FixedSubdivCheckBox, "Fixed subdivision of the circle" );

    fixedsubdiv = FixedSubdivCheckBox->isChecked();

    DataForMethodsBoxLayout->addWidget( FixedSubdivCheckBox, 4, 0 );

    connect(FixedSubdivCheckBox,SIGNAL(toggled(bool)),SLOT(CheckBoxToggled()));

    OptimizationCheckBox = new QCheckBox( DataForMethodsBox, "OptimizationCheckBox" );
    QFont OptimizationCheckBox_font(  OptimizationCheckBox->font() );
    OptimizationCheckBox_font.setPointSize( 11 );
    OptimizationCheckBox->setFont( OptimizationCheckBox_font ); 
    OptimizationCheckBox->setText( "Order optimization:" );
    OptimizationCheckBox->setChecked( true );
    OptimizationCheckBox->setEnabled( ( M2 || M4 ) && fixedsubdiv );
    QToolTip::add( OptimizationCheckBox, "Optimization of the order of the Taylor polynomial" );

    optimization = OptimizationCheckBox->isChecked();

    DataForMethodsBoxLayout->addWidget( OptimizationCheckBox, 5, 0 );

    connect(OptimizationCheckBox,SIGNAL(toggled(bool)),SLOT(CheckBoxToggled()));


    data[ Test4Edit ] = new QLineEdit( DataForMethodsBox, "Test4Edit" );
    QFont Test4Edit_font(  data[ Test4Edit ]->font() );
    Test4Edit_font.setPointSize( 11 );
    data[ Test4Edit ]->setFont( Test4Edit_font ); 
    data[ Test4Edit ]->setText( defaultValues[ Test4Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ Test4Edit ], 5, 5 );

    RelErrLabel = new QLabel( DataForMethodsBox, "RelErrLabel" );
    QFont RelErrLabel_font(  RelErrLabel->font() );
    RelErrLabel_font.setPointSize( 11 );
    RelErrLabel->setFont( RelErrLabel_font ); 
    RelErrLabel->setText( "Acceptable relative error:" );
    RelErrLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignLeft ) );

    DataForMethodsBoxLayout->addMultiCellWidget( RelErrLabel, 10, 10, 0, 1 );

    data[ MinNoSeg1Edit ] = new QLineEdit( DataForMethodsBox, "MinNoSeg1Edit" );
    QFont MinNoSeg1Edit_font(  data[ MinNoSeg1Edit ]->font() );
    MinNoSeg1Edit_font.setPointSize( 11 );
    data[ MinNoSeg1Edit ]->setFont( MinNoSeg1Edit_font ); 
    data[ MinNoSeg1Edit ]->setText( defaultValues[ MinNoSeg1Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ MinNoSeg1Edit ], 9, 2 );

    data[ MaxNoSeg3Edit ] = new QLineEdit( DataForMethodsBox, "MaxNoSeg3Edit" );
    QFont MaxNoSeg3Edit_font(  data[ MaxNoSeg3Edit ]->font() );
    MaxNoSeg3Edit_font.setPointSize( 11 );
    data[ MaxNoSeg3Edit ]->setFont( MaxNoSeg3Edit_font ); 
    data[ MaxNoSeg3Edit ]->setText( defaultValues[ MaxNoSeg3Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ MaxNoSeg3Edit ], 8, 4 );

    PrecisionLabel = new QLabel( DataForMethodsBox, "PrecisionLabel" );
    QFont PrecisionLabel_font(  PrecisionLabel->font() );
    PrecisionLabel_font.setPointSize( 11 );
    PrecisionLabel->setFont( PrecisionLabel_font ); 
    PrecisionLabel->setText( "Precision of the Taylor coefficients:" );
    PrecisionLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignLeft ) );

    DataForMethodsBoxLayout->addMultiCellWidget( PrecisionLabel, 2, 2, 0, 1 );

    MaxOrderLabel = new QLabel( DataForMethodsBox, "MaxOrderLabel" );
    QFont MaxOrderLabel_font(  MaxOrderLabel->font() );
    MaxOrderLabel_font.setPointSize( 11 );
    MaxOrderLabel->setFont( MaxOrderLabel_font ); 
    MaxOrderLabel->setText( "Max. order:" );
    MaxOrderLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignLeft ) );
    QToolTip::add(  MaxOrderLabel, "Maximum order of Taylor polynomial" );

    DataForMethodsBoxLayout->addWidget( MaxOrderLabel, 6, 1 );

    data[ RelErr4Edit ] = new QLineEdit( DataForMethodsBox, "RelErr4Edit" );
    QFont RelErr4Edit_font(  data[ RelErr4Edit ]->font() );
    RelErr4Edit_font.setPointSize( 11 );
    data[ RelErr4Edit ]->setFont( RelErr4Edit_font ); 
    data[ RelErr4Edit ]->setText( defaultValues[ RelErr4Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ RelErr4Edit ], 10, 5 );

    data[ OrderTaylMeth2Edit ] = new QLineEdit( DataForMethodsBox, "OrderTaylMeth2Edit" );
    QFont OrderTaylMeth2Edit_font(  data[ OrderTaylMeth2Edit ]->font() );
    OrderTaylMeth2Edit_font.setPointSize( 11 );
    data[ OrderTaylMeth2Edit ]->setFont( OrderTaylMeth2Edit_font ); 
    data[ OrderTaylMeth2Edit ]->setText( defaultValues[ OrderTaylMeth2Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ OrderTaylMeth2Edit ], 1, 3 );

    data[ AbsErr4Edit ] = new QLineEdit( DataForMethodsBox, "AbsErr4Edit" );
    QFont AbsErr4Edit_font(  data[ AbsErr4Edit ]->font() );
    AbsErr4Edit_font.setPointSize( 11 );
    data[ AbsErr4Edit ]->setFont( AbsErr4Edit_font );
    data[ AbsErr4Edit ]->setText( defaultValues[ AbsErr4Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ AbsErr4Edit ], 11, 5 );

    data[ MaxTime2Edit ] = new QLineEdit( DataForMethodsBox, "MaxTime2Edit" );
    QFont MaxTime2Edit_font(  data[ MaxTime2Edit ]->font() );
    MaxTime2Edit_font.setPointSize( 11 );
    data[ MaxTime2Edit ]->setFont( MaxTime2Edit_font );
    data[ MaxTime2Edit ]->setText( defaultValues[ MaxTime2Edit ] ); 

    QToolTip::add( data[ MaxTime2Edit ], "0 = No restriction" );

    DataForMethodsBoxLayout->addWidget( data[ MaxTime2Edit ], 12, 3 );

    data[ MaxOrd2Edit ] = new QLineEdit( DataForMethodsBox, "MaxOrd2Edit" );
    QFont MaxOrd2Edit_font(  data[ MaxOrd2Edit ]->font() );
    MaxOrd2Edit_font.setPointSize( 11 );
    data[ MaxOrd2Edit ]->setFont( MaxOrd2Edit_font );
    data[ MaxOrd2Edit ]->setText( defaultValues[ MaxOrd2Edit ] );
    data[ MaxOrd2Edit ]->setEnabled( M2 && fixedsubdiv && optimization ); 

    DataForMethodsBoxLayout->addWidget( data[ MaxOrd2Edit ], 6, 3 );

    MaxCompTimeLabel = new QLabel( DataForMethodsBox, "MaxCompTimeLabel" );
    QFont MaxCompTimeLabel_font(  MaxCompTimeLabel->font() );
    MaxCompTimeLabel_font.setPointSize( 11 );
    MaxCompTimeLabel->setFont( MaxCompTimeLabel_font ); 
    MaxCompTimeLabel->setText( "Maximum computation time (seconds):  " );
    MaxCompTimeLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignLeft ) );

    DataForMethodsBoxLayout->addMultiCellWidget( MaxCompTimeLabel, 12, 12, 0, 1 );

    data[ RelErr1Edit ] = new QLineEdit( DataForMethodsBox, "RelErr1Edit" );
    QFont RelErr1Edit_font(  data[ RelErr1Edit ]->font() );
    RelErr1Edit_font.setPointSize( 11 );
    data[ RelErr1Edit ]->setFont( RelErr1Edit_font );
    data[ RelErr1Edit ]->setText( defaultValues[ RelErr1Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ RelErr1Edit ], 10, 2 );

    data[ PrecTayl2Edit ] = new QLineEdit( DataForMethodsBox, "PrecTayl2Edit" );
    QFont PrecTayl2Edit_font(  data[ PrecTayl2Edit ]->font() );
    PrecTayl2Edit_font.setPointSize( 11 );
    data[ PrecTayl2Edit ]->setFont( PrecTayl2Edit_font );
    data[ PrecTayl2Edit ]->setText( defaultValues[ PrecTayl2Edit ] ); 
    data[ PrecTayl2Edit ]->setEnabled( false ); 
    QToolTip::add( data[ PrecTayl2Edit ], "Not yet implemented" );

    DataForMethodsBoxLayout->addWidget( data[ PrecTayl2Edit ], 2, 3 );

    data[ OrdDeriv3Edit ] = new QLineEdit( DataForMethodsBox, "OrdDeriv3Edit" );
    QFont OrdDeriv3Edit_font(  data[ OrdDeriv3Edit ]->font() );
    OrdDeriv3Edit_font.setPointSize( 11 );
    data[ OrdDeriv3Edit ]->setFont( OrdDeriv3Edit_font ); 
    data[ OrdDeriv3Edit ]->setText( defaultValues[ OrdDeriv3Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ OrdDeriv3Edit ], 3, 4 );

    data[ Test2Edit ] = new QLineEdit( DataForMethodsBox, "Test2Edit" );
    QFont Test2Edit_font(  data[ Test2Edit ]->font() );
    Test2Edit_font.setPointSize( 11 );
    data[ Test2Edit ]->setFont( Test2Edit_font ); 
    data[ Test2Edit ]->setText( defaultValues[ Test2Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ Test2Edit ], 5, 3 );

    Method3InputLabel = new QLabel( DataForMethodsBox, "Method3InputLabel" );
    QFont Method3InputLabel_font(  Method3InputLabel->font() );
    Method3InputLabel_font.setPointSize( 11 );
    Method3InputLabel->setFont( Method3InputLabel_font ); 
    Method3InputLabel->setText( "Method III" );
    Method3InputLabel->setAlignment( int( QLabel::AlignCenter ) );

    DataForMethodsBoxLayout->addWidget( Method3InputLabel, 0, 4 );

    data[ OrdDeriv4Edit ] = new QLineEdit( DataForMethodsBox, "OrdDeriv4Edit" );
    QFont OrdDeriv4Edit_font(  data[ OrdDeriv4Edit ]->font() );
    OrdDeriv4Edit_font.setPointSize( 11 );
    data[ OrdDeriv4Edit ]->setFont( OrdDeriv4Edit_font ); 
    data[ OrdDeriv4Edit ]->setText( defaultValues[ OrdDeriv4Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ OrdDeriv4Edit ], 3, 5 );

    data[ MaxNoSeg4Edit ] = new QLineEdit( DataForMethodsBox, "MaxNoSeg4Edit" );
    QFont MaxNoSeg4Edit_font(  data[ MaxNoSeg4Edit ]->font() );
    MaxNoSeg4Edit_font.setPointSize( 11 );
    data[ MaxNoSeg4Edit ]->setFont( MaxNoSeg4Edit_font ); 
    data[ MaxNoSeg4Edit ]->setText( defaultValues[ MaxNoSeg4Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ MaxNoSeg4Edit ], 8, 5 );

    data[ MaxTime3Edit ] = new QLineEdit( DataForMethodsBox, "MaxTime3Edit" );
    QFont MaxTime3Edit_font(  data[ MaxTime3Edit ]->font() );
    MaxTime3Edit_font.setPointSize( 11 );
    data[ MaxTime3Edit ]->setFont( MaxTime3Edit_font ); 
    data[ MaxTime3Edit ]->setText( defaultValues[ MaxTime3Edit ] ); 

    QToolTip::add( data[ MaxTime3Edit ], "0 = No restriction" );

    DataForMethodsBoxLayout->addWidget( data[ MaxTime3Edit ], 12, 4 );

    data[ MinNoSeg4Edit ] = new QLineEdit( DataForMethodsBox, "MinNoSeg4Edit" );
    QFont MinNoSeg4Edit_font(  data[ MinNoSeg4Edit ]->font() );
    MinNoSeg4Edit_font.setPointSize( 11 );
    data[ MinNoSeg4Edit ]->setFont( MinNoSeg4Edit_font ); 
    data[ MinNoSeg4Edit ]->setText( defaultValues[ MinNoSeg4Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ MinNoSeg4Edit ], 9, 5 );

    data[ AbsErr3Edit ] = new QLineEdit( DataForMethodsBox, "AbsErr3Edit" );
    QFont AbsErr3Edit_font(  data[ AbsErr3Edit ]->font() );
    AbsErr3Edit_font.setPointSize( 11 );
    data[ AbsErr3Edit ]->setFont( AbsErr3Edit_font ); 
    data[ AbsErr3Edit ]->setText( defaultValues[ AbsErr3Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ AbsErr3Edit ], 11, 4 );

    AbsErrLabel = new QLabel( DataForMethodsBox, "AbsErrLabel" );
    QFont AbsErrLabel_font(  AbsErrLabel->font() );
    AbsErrLabel_font.setPointSize( 11 );
    AbsErrLabel->setFont( AbsErrLabel_font ); 
    AbsErrLabel->setText( "Acceptable absolute error:" );
    AbsErrLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignLeft ) );

    DataForMethodsBoxLayout->addMultiCellWidget( AbsErrLabel, 11, 11, 0, 1 );

    data[ PrecTayl4Edit ] = new QLineEdit( DataForMethodsBox, "PrecTayl4Edit" );
    QFont PrecTayl4Edit_font(  data[ PrecTayl4Edit ]->font() );
    PrecTayl4Edit_font.setPointSize( 11 );
    data[ PrecTayl4Edit ]->setFont( PrecTayl4Edit_font ); 
    data[ PrecTayl4Edit ]->setText( defaultValues[ PrecTayl4Edit ] ); 
    data[ PrecTayl4Edit ]->setEnabled( false ); 
    QToolTip::add( data[ PrecTayl4Edit ], "Not yet implemented" );

    DataForMethodsBoxLayout->addWidget( data[ PrecTayl4Edit ], 2, 5 );

    TestLabel = new QLabel( DataForMethodsBox, "TestLabel" );
    QFont TestLabel_font(  TestLabel->font() );
    TestLabel_font.setPointSize( 11 );
    TestLabel->setFont( TestLabel_font ); 
    TestLabel->setText( "Test segments:" );
    TestLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignLeft ) );

    DataForMethodsBoxLayout->addWidget( TestLabel, 5, 1 );

    data[ OrderTaylMeth4Edit ] = new QLineEdit( DataForMethodsBox, "OrderTaylMeth4Edit" );
    QFont OrderTaylMeth4Edit_font(  data[ OrderTaylMeth4Edit ]->font() );
    OrderTaylMeth4Edit_font.setPointSize( 11 );
    data[ OrderTaylMeth4Edit ]->setFont( OrderTaylMeth4Edit_font ); 
    data[ OrderTaylMeth4Edit ]->setText( defaultValues[ OrderTaylMeth4Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ OrderTaylMeth4Edit ], 1, 5 );

    data[ MaxOrd4Edit ] = new QLineEdit( DataForMethodsBox, "MaxOrd4Edit" );
    QFont MaxOrd4Edit_font(  data[ MaxOrd4Edit ]->font() );
    MaxOrd4Edit_font.setPointSize( 11 );
    data[ MaxOrd4Edit ]->setFont( MaxOrd4Edit_font ); 
    data[ MaxOrd4Edit ]->setText( defaultValues[ MaxOrd4Edit ] ); 
    data[ MaxOrd4Edit ]->setEnabled( M4 && fixedsubdiv && optimization );

    DataForMethodsBoxLayout->addWidget( data[ MaxOrd4Edit ], 6, 5 );

    data[ MaxTime1Edit ] = new QLineEdit( DataForMethodsBox, "MaxTime1Edit" );
    QFont MaxTime1Edit_font(  data[ MaxTime1Edit ]->font() );
    MaxTime1Edit_font.setPointSize( 11 );
    data[ MaxTime1Edit ]->setFont( MaxTime1Edit_font ); 
    data[ MaxTime1Edit ]->setText( defaultValues[ MaxTime1Edit ] ); 

    QToolTip::add( data[ MaxTime1Edit ], "0 = No restriction" );

    DataForMethodsBoxLayout->addWidget( data[ MaxTime1Edit ], 12, 2 );

    Method1InputLabel = new QLabel( DataForMethodsBox, "Method1InputLabel" );
    QFont Method1InputLabel_font(  Method1InputLabel->font() );
    Method1InputLabel_font.setPointSize( 11 );
    Method1InputLabel->setFont( Method1InputLabel_font ); 
    Method1InputLabel->setText( "Method I" );
    Method1InputLabel->setAlignment( int( QLabel::AlignCenter ) );

    DataForMethodsBoxLayout->addWidget( Method1InputLabel, 0, 2 );

    OrderLabel = new QLabel( DataForMethodsBox, "OrderLabel" );
    QFont OrderLabel_font(  OrderLabel->font() );
    OrderLabel_font.setPointSize( 11 );
    OrderLabel->setFont( OrderLabel_font ); 
    OrderLabel->setText( "Order of the Taylor polynomial:" );
    OrderLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignLeft ) );

    DataForMethodsBoxLayout->addMultiCellWidget( OrderLabel, 1, 1, 0, 1 );

    data[ RelErr3Edit ] = new QLineEdit( DataForMethodsBox, "RelErr3Edit" );
    QFont RelErr3Edit_font(  data[ RelErr3Edit ]->font() );
    RelErr3Edit_font.setPointSize( 11 );
    data[ RelErr3Edit ]->setFont( RelErr3Edit_font ); 
    data[ RelErr3Edit ]->setText( defaultValues[ RelErr3Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ RelErr3Edit ], 10, 4 );

    data[ MinNoSeg3Edit ] = new QLineEdit( DataForMethodsBox, "MinNoSeg3Edit" );
    QFont MinNoSeg3Edit_font(  data[ MinNoSeg3Edit ]->font() );
    MinNoSeg3Edit_font.setPointSize( 11 );
    data[ MinNoSeg3Edit ]->setFont( MinNoSeg3Edit_font ); 
    data[ MinNoSeg3Edit ]->setText( defaultValues[ MinNoSeg3Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ MinNoSeg3Edit ], 9, 4 );

    Method4InputLabel = new QLabel( DataForMethodsBox, "Method4InputLabel" );
    QFont Method4InputLabel_font(  Method4InputLabel->font() );
    Method4InputLabel_font.setPointSize( 11 );
    Method4InputLabel->setFont( Method4InputLabel_font ); 
    Method4InputLabel->setText( "Method IV" );
    Method4InputLabel->setAlignment( int( QLabel::AlignCenter ) );

    DataForMethodsBoxLayout->addWidget( Method4InputLabel, 0, 5 );

    data[ AbsErr2Edit ] = new QLineEdit( DataForMethodsBox, "AbsErr2Edit" );
    QFont AbsErr2Edit_font(  data[ AbsErr2Edit ]->font() );
    AbsErr2Edit_font.setPointSize( 11 );
    data[ AbsErr2Edit ]->setFont( AbsErr2Edit_font ); 
    data[ AbsErr2Edit ]->setText( defaultValues[ AbsErr2Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ AbsErr2Edit ], 11, 3 );

    data[ MaxNoSeg1Edit ] = new QLineEdit( DataForMethodsBox, "MaxNoSeg1Edit" );
    QFont MaxNoSeg1Edit_font(  data[ MaxNoSeg1Edit ]->font() );
    MaxNoSeg1Edit_font.setPointSize( 11 );
    data[ MaxNoSeg1Edit ]->setFont( MaxNoSeg1Edit_font ); 
    data[ MaxNoSeg1Edit ]->setText( defaultValues[ MaxNoSeg1Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ MaxNoSeg1Edit ], 8, 2 );

    data[ MaxTime4Edit ] = new QLineEdit( DataForMethodsBox, "MaxTime4Edit" );
    QFont MaxTime4Edit_font(  data[ MaxTime4Edit ]->font() );
    MaxTime4Edit_font.setPointSize( 11 );
    data[ MaxTime4Edit ]->setFont( MaxTime4Edit_font ); 
    data[ MaxTime4Edit ]->setText( defaultValues[ MaxTime4Edit ] ); 

    QToolTip::add( data[ MaxTime4Edit ], "0 = No restriction" );

    DataForMethodsBoxLayout->addWidget( data[ MaxTime4Edit ], 12, 5 );

    data[ AbsErr1Edit ] = new QLineEdit( DataForMethodsBox, "AbsErr1Edit" );
    QFont AbsErr1Edit_font(  data[ AbsErr1Edit ]->font() );
    AbsErr1Edit_font.setPointSize( 11 );
    data[ AbsErr1Edit ]->setFont( AbsErr1Edit_font ); 
    data[ AbsErr1Edit ]->setText( defaultValues[ AbsErr1Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ AbsErr1Edit ], 11, 2 );

    Method2InputLabel = new QLabel( DataForMethodsBox, "Method2InputLabel" );
    QFont Method2InputLabel_font(  Method2InputLabel->font() );
    Method2InputLabel_font.setPointSize( 11 );
    Method2InputLabel->setFont( Method2InputLabel_font ); 
    Method2InputLabel->setText( "Method II" );
    Method2InputLabel->setAlignment( int( QLabel::AlignCenter ) );

    DataForMethodsBoxLayout->addWidget( Method2InputLabel, 0, 3 );

    DerivativeLabel = new QLabel( DataForMethodsBox, "DerivativeLabel" );
    QFont DerivativeLabel_font(  DerivativeLabel->font() );
    DerivativeLabel_font.setPointSize( 11 );
    DerivativeLabel->setFont( DerivativeLabel_font ); 
    DerivativeLabel->setText( "Order of the derivative:" );
    DerivativeLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignLeft ) );

    DataForMethodsBoxLayout->addMultiCellWidget( DerivativeLabel, 3, 3, 0, 1 );

    data[ RelErr2Edit ] = new QLineEdit( DataForMethodsBox, "RelErr2Edit" );
    QFont RelErr2Edit_font(  data[ RelErr2Edit ]->font() );
    RelErr2Edit_font.setPointSize( 11 );
    data[ RelErr2Edit ]->setFont( RelErr2Edit_font ); 
    data[ RelErr2Edit ]->setText( defaultValues[ RelErr2Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ RelErr2Edit ], 10, 3 );

    MinNoSegLabel = new QLabel( DataForMethodsBox, "MinNoSegLabel" );
    QFont MinNoSegLabel_font(  MinNoSegLabel->font() );
    MinNoSegLabel_font.setPointSize( 11 );
    MinNoSegLabel->setFont( MinNoSegLabel_font ); 
    MinNoSegLabel->setText( "Minimum no. of active segments:" );
    MinNoSegLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignLeft ) );

    DataForMethodsBoxLayout->addMultiCellWidget( MinNoSegLabel, 9, 9, 0, 1 );

    data[ MinNoSeg2Edit ] = new QLineEdit( DataForMethodsBox, "MinNoSeg2Edit" );
    QFont MinNoSeg2Edit_font(  data[ MinNoSeg2Edit ]->font() );
    MinNoSeg2Edit_font.setPointSize( 11 );
    data[ MinNoSeg2Edit ]->setFont( MinNoSeg2Edit_font ); 
    data[ MinNoSeg2Edit ]->setText( defaultValues[ MinNoSeg2Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ MinNoSeg2Edit ], 9, 3 );

    data[ MaxNoSeg2Edit ] = new QLineEdit( DataForMethodsBox, "MaxNoSeg2Edit" );
    QFont MaxNoSeg2Edit_font(  data[ MaxNoSeg2Edit ]->font() );
    MaxNoSeg2Edit_font.setPointSize( 11 );
    data[ MaxNoSeg2Edit ]->setFont( MaxNoSeg2Edit_font ); 
    data[ MaxNoSeg2Edit ]->setText( defaultValues[ MaxNoSeg2Edit ] ); 

    DataForMethodsBoxLayout->addWidget( data[ MaxNoSeg2Edit ], 8, 3 );

    MaxNoSegLabel = new QLabel( DataForMethodsBox, "MaxNoSegLabel" );
    QFont MaxNoSegLabel_font(  MaxNoSegLabel->font() );
    MaxNoSegLabel_font.setPointSize( 11 );
    MaxNoSegLabel->setFont( MaxNoSegLabel_font ); 
    MaxNoSegLabel->setText( "Maximum no. of active segments:" );
    MaxNoSegLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignLeft ) );

    DataForMethodsBoxLayout->addMultiCellWidget( MaxNoSegLabel, 8, 8, 0, 1 );

    QSpacerItem* spacer_10 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    DataForMethodsBoxLayout->addItem( spacer_10, 1, 2 );
    QSpacerItem* spacer_11 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    DataForMethodsBoxLayout->addItem( spacer_11, 2, 2 );
    QSpacerItem* spacer_12 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    DataForMethodsBoxLayout->addItem( spacer_12, 1, 4 );
    QSpacerItem* spacer_13 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    DataForMethodsBoxLayout->addItem( spacer_13, 5, 2 );
    QSpacerItem* spacer_14 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    DataForMethodsBoxLayout->addItem( spacer_14, 6, 4 );
    QSpacerItem* spacer_15 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    DataForMethodsBoxLayout->addItem( spacer_15, 3, 3 );
    QSpacerItem* spacer_16 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    DataForMethodsBoxLayout->addItem( spacer_16, 4, 5 );
    QSpacerItem* spacer_17 = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
    DataForMethodsBoxLayout->addItem( spacer_17, 4, 1 );
    QSpacerItem* spacer_18 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    DataForMethodsBoxLayout->addItem( spacer_18, 2, 4 );
    QSpacerItem* spacer_19 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    DataForMethodsBoxLayout->addItem( spacer_19, 4, 2 );
    QSpacerItem* spacer_20 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    DataForMethodsBoxLayout->addItem( spacer_20, 4, 3 );
    QSpacerItem* spacer_21 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    DataForMethodsBoxLayout->addItem( spacer_21, 4, 4 );
    QSpacerItem* spacer_22 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    DataForMethodsBoxLayout->addItem( spacer_22, 3, 2 );
    QSpacerItem* spacer_23 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    DataForMethodsBoxLayout->addItem( spacer_23, 5, 4 );    
    QSpacerItem* spacer_24 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    DataForMethodsBoxLayout->addItem( spacer_24, 6, 3 );    
    QSpacerItem* spacer_25 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    DataForMethodsBoxLayout->addItem( spacer_25, 7, 2 );
    QSpacerItem* spacer_26 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    DataForMethodsBoxLayout->addItem( spacer_26, 7, 3 );
    QSpacerItem* spacer_27 = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
    DataForMethodsBoxLayout->addItem( spacer_27, 7, 1 );

    InputWidgetLayout->addWidget( DataForMethodsBox );

    Layout14 = new QHBoxLayout; 
    Layout14->setSpacing( 6 );
    Layout14->setMargin( 0 );

    //
    //Bounds Box
    //
    BoundsBox = new QGroupBox( this, "BoundsBox" );
    QFont BoundsBox_font(  BoundsBox->font() );
    BoundsBox_font.setFamily( "adobe-helvetica" );
    BoundsBox_font.setPointSize( 12 );
    BoundsBox->setFont( BoundsBox_font ); 
    BoundsBox->setTitle( "Compute bounds for a_k" );
    BoundsBox->setColumnLayout(0, Qt::Vertical );
    BoundsBox->layout()->setSpacing( 0 );
    BoundsBox->layout()->setMargin( 0 );

    BoundsBoxLayout = new QHBoxLayout( BoundsBox->layout() );
    BoundsBoxLayout->setAlignment( Qt::AlignTop );
    BoundsBoxLayout->setSpacing( 6 );
    BoundsBoxLayout->setMargin( 11 );

    BoundsLabel = new QLabel( BoundsBox, "BoundsLabel" );
    QFont BoundsLabel_font(  BoundsLabel->font() );
    BoundsLabel_font.setPointSize( 11 );
    BoundsLabel->setFont( BoundsLabel_font ); 
    BoundsLabel->setText( "k = " );
    BoundsBoxLayout->addWidget( BoundsLabel );

    Bounds_ListBox = new QMultiLineEdit( BoundsBox, "Bounds_ListBox" );
    Bounds_ListBox->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7, (QSizePolicy::SizeType)3, Bounds_ListBox->sizePolicy().hasHeightForWidth() ) );
    Bounds_ListBox->setMinimumSize( QSize( 0, 20 ) );
    QFont Bounds_ListBox_font(  Bounds_ListBox->font() );
    Bounds_ListBox_font.setPointSize( 11 );
    Bounds_ListBox->setFont( Bounds_ListBox_font ); 
    Bounds_ListBox->setText( defaultValues[ 33 ] ); 
    BoundsBoxLayout->addWidget( Bounds_ListBox );
    Layout14->addWidget( BoundsBox );
    QToolTip::add( Bounds_ListBox, "Indexes k, for which explicit bounds for |a_k| are calculated." ); 

    //
    //Remainders Box
    //
    RemaindersBox = new QGroupBox( this, "RemaindersBox" );
    QFont RemaindersBox_font(  RemaindersBox->font() );
    RemaindersBox_font.setFamily( "adobe-helvetica" );
    RemaindersBox_font.setPointSize( 12 );
    RemaindersBox->setFont( RemaindersBox_font ); 
    RemaindersBox->setTitle( "Compute bounds for remainders R_p" );
    RemaindersBox->setColumnLayout(0, Qt::Vertical );
    RemaindersBox->layout()->setSpacing( 0 );
    RemaindersBox->layout()->setMargin( 0 );
    RemaindersBoxLayout = new QHBoxLayout( RemaindersBox->layout() );
    RemaindersBoxLayout->setAlignment( Qt::AlignTop );
    RemaindersBoxLayout->setSpacing( 6 );
    RemaindersBoxLayout->setMargin( 11 );

    RemaindersLabel = new QLabel( RemaindersBox, "RemaindersLabel" );
    QFont RemaindersLabel_font(  RemaindersLabel->font() );
    RemaindersLabel_font.setPointSize( 11 );
    RemaindersLabel->setFont( RemaindersLabel_font ); 
    RemaindersLabel->setText( "p = " );
    RemaindersBoxLayout->addWidget( RemaindersLabel );

    Remainders_ListBox = new QMultiLineEdit( RemaindersBox, "Remainders_ListBox" );
    Remainders_ListBox->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7, (QSizePolicy::SizeType)3, Remainders_ListBox->sizePolicy().hasHeightForWidth() ) );
    Remainders_ListBox->setMinimumSize( QSize( 0, 20 ) );
    QFont Remainders_ListBox_font(  Remainders_ListBox->font() );
    Remainders_ListBox_font.setPointSize( 11 );
    Remainders_ListBox->setFont( Remainders_ListBox_font ); 
    Remainders_ListBox->setText( defaultValues[ 34 ] ); 
    RemaindersBoxLayout->addWidget( Remainders_ListBox );
    Layout14->addWidget( RemaindersBox );
    QToolTip::add( Remainders_ListBox, "Indexes p, for which explicit bounds for |R_p(omega*r)| are calculated." ); 

    //
    //Omega Box
    //
    OmegaBox = new QGroupBox( this, "OmegaBox" );
    QFont OmegaBox_font(  OmegaBox->font() );
    OmegaBox_font.setFamily( "adobe-helvetica" );
    OmegaBox_font.setPointSize( 12 );
    OmegaBox->setFont( OmegaBox_font ); 
    OmegaBox->setTitle( "Parameter values for omega" );
    OmegaBox->setColumnLayout(0, Qt::Vertical );
    OmegaBox->layout()->setSpacing( 0 );
    OmegaBox->layout()->setMargin( 0 );
    OmegaBoxLayout = new QHBoxLayout( OmegaBox->layout() );
    OmegaBoxLayout->setAlignment( Qt::AlignTop );
    OmegaBoxLayout->setSpacing( 6 );
    OmegaBoxLayout->setMargin( 11 );

    OmegaLabel = new QLabel( OmegaBox, "OmegaLabel" );
    QFont OmegaLabel_font(  OmegaLabel->font() );
    OmegaLabel_font.setPointSize( 11 );
    OmegaLabel->setFont( OmegaLabel_font ); 
    OmegaLabel->setText( "omega = " );
    OmegaBoxLayout->addWidget( OmegaLabel );

    Omega_ListBox = new QMultiLineEdit( OmegaBox, "Omega_ListBox" );
    Omega_ListBox->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7, (QSizePolicy::SizeType)3, Omega_ListBox->sizePolicy().hasHeightForWidth() ) );
    Omega_ListBox->setMinimumSize( QSize( 0, 20 ) );
    QFont Omega_ListBox_font(  Omega_ListBox->font() );
    Omega_ListBox_font.setPointSize( 11 );
    Omega_ListBox->setFont( Omega_ListBox_font ); 
    Omega_ListBox->setText( defaultValues[ 35 ] ); 
    OmegaBoxLayout->addWidget( Omega_ListBox );
    Layout14->addWidget( OmegaBox );
    InputWidgetLayout->addLayout( Layout14 );
    QToolTip::add( Omega_ListBox, "Values of omega, for which explicit bounds for |R_p(omega*r)| are calculated." ); 

    //
    //Tab order
    //
    setTabOrder( data[ ExprEdit ], data[ CenterEdit ] );
    setTabOrder( data[ CenterEdit ], data[ RadiusEdit ] );
    setTabOrder( data[ RadiusEdit ], Method1_CheckBox );
    setTabOrder( Method1_CheckBox, Method2_CheckBox );
    setTabOrder( Method2_CheckBox, Method3_CheckBox );
    setTabOrder( Method3_CheckBox, Method4_CheckBox );
    setTabOrder( Method4_CheckBox, Verbose_CheckBox );
    setTabOrder( Verbose_CheckBox, data[ OrderTaylMeth2Edit ] );
    setTabOrder( data[ OrderTaylMeth2Edit ], data[ OrderTaylMeth4Edit ] );
    setTabOrder( data[ OrderTaylMeth4Edit ], data[ PrecTayl2Edit ] );
    setTabOrder( data[ PrecTayl2Edit ], data[ PrecTayl4Edit ] );
    setTabOrder( data[ PrecTayl4Edit ], data[ OrdDeriv3Edit ] );
    setTabOrder( data[ OrdDeriv3Edit ], data[ OrdDeriv4Edit ] );
    setTabOrder( data[ OrdDeriv4Edit ], FixedSubdivCheckBox );
    setTabOrder( FixedSubdivCheckBox, OptimizationCheckBox );
    setTabOrder( OptimizationCheckBox, data[ Test2Edit ] );
    setTabOrder( data[ Test2Edit ], data[ Test4Edit ] );
    setTabOrder( data[ Test4Edit ], data[ MaxOrd2Edit ] );
    setTabOrder( data[ MaxOrd2Edit ], data[ MaxOrd4Edit ] );
    setTabOrder( data[ MaxOrd4Edit ], data[ MaxNoSeg1Edit ] );
    setTabOrder( data[ MaxNoSeg1Edit ], data[ MaxNoSeg2Edit ] );
    setTabOrder( data[ MaxNoSeg2Edit ], data[ MaxNoSeg3Edit ] );
    setTabOrder( data[ MaxNoSeg3Edit ], data[ MaxNoSeg4Edit ] );
    setTabOrder( data[ MaxNoSeg4Edit ], data[ MinNoSeg1Edit ] );
    setTabOrder( data[ MinNoSeg1Edit ], data[ MinNoSeg2Edit ] );
    setTabOrder( data[ MinNoSeg2Edit ], data[ MinNoSeg3Edit ] );
    setTabOrder( data[ MinNoSeg3Edit ], data[ MinNoSeg4Edit ] );
    setTabOrder( data[ MinNoSeg4Edit ], data[ RelErr1Edit ] );
    setTabOrder( data[ RelErr1Edit ], data[ RelErr2Edit ] );
    setTabOrder( data[ RelErr2Edit ], data[ RelErr3Edit ] );
    setTabOrder( data[ RelErr3Edit ], data[ RelErr4Edit ] );
    setTabOrder( data[ RelErr4Edit ], data[ AbsErr1Edit ] );
    setTabOrder( data[ AbsErr1Edit ], data[ AbsErr2Edit ] );
    setTabOrder( data[ AbsErr2Edit ], data[ AbsErr3Edit ] );
    setTabOrder( data[ AbsErr3Edit ], data[ AbsErr4Edit ] );
    setTabOrder( data[ AbsErr4Edit ], data[ MaxTime1Edit ] );
    setTabOrder( data[ MaxTime1Edit ], data[ MaxTime2Edit ] );
    setTabOrder( data[ MaxTime2Edit ], data[ MaxTime3Edit ] );
    setTabOrder( data[ MaxTime3Edit ], data[ MaxTime4Edit ] );
    setTabOrder( data[ MaxTime4Edit ], Bounds_ListBox );
    setTabOrder( Bounds_ListBox, Remainders_ListBox );
    setTabOrder( Remainders_ListBox, Omega_ListBox );

    activateM( 1 );
    activateM( 2 );
    activateM( 3 );
    activateM( 4 );
}

/*  
 *  Destroys the object and frees any allocated resources
 */
InputWidget::~InputWidget()
{
    // no need to delete child widgets, Qt does it all for us
}

/*  
 *  Main event handler. Reimplemented to handle application
 *  font changes
 */
bool InputWidget::event( QEvent* ev )
{
    bool ret = QWidget::event( ev ); 
    if ( ev->type() == QEvent::ApplicationFontChange ) {
	QFont ExprBox_font(  ExprBox->font() );
	ExprBox_font.setFamily( "adobe-helvetica" );
	ExprBox_font.setPointSize( 12 );
	ExprBox->setFont( ExprBox_font ); 
	QFont ExprLabel_font(  ExprLabel->font() );
	ExprLabel_font.setPointSize( 11 );
	ExprLabel->setFont( ExprLabel_font ); 
	QFont ExprEdit_font(  data[ ExprEdit ]->font() );
	ExprEdit_font.setPointSize( 11 );
	data[ ExprEdit ]->setFont( ExprEdit_font ); 
	QFont MethodsBox_font(  MethodsBox->font() );
	MethodsBox_font.setFamily( "adobe-helvetica" );
	MethodsBox_font.setPointSize( 12 );
	MethodsBox->setFont( MethodsBox_font ); 
	QFont Method3_CheckBox_font(  Method3_CheckBox->font() );
	Method3_CheckBox_font.setPointSize( 11 );
	Method3_CheckBox->setFont( Method3_CheckBox_font ); 
	QFont Method4_CheckBox_font(  Method4_CheckBox->font() );
	Method4_CheckBox_font.setPointSize( 11 );
	Method4_CheckBox->setFont( Method4_CheckBox_font ); 
	QFont Method1_CheckBox_font(  Method1_CheckBox->font() );
	Method1_CheckBox_font.setPointSize( 11 );
	Method1_CheckBox->setFont( Method1_CheckBox_font ); 
	QFont Method2_CheckBox_font(  Method2_CheckBox->font() );
	Method2_CheckBox_font.setPointSize( 11 );
	Method2_CheckBox->setFont( Method2_CheckBox_font ); 
	QFont Verbose_CheckBox_font(  Verbose_CheckBox->font() );
	Verbose_CheckBox_font.setPointSize( 11 );
	Verbose_CheckBox->setFont( Verbose_CheckBox_font ); 
	QFont DomainBox_font(  DomainBox->font() );
	DomainBox_font.setFamily( "adobe-helvetica" );
	DomainBox_font.setPointSize( 12 );
	DomainBox->setFont( DomainBox_font ); 
	QFont CenterLabel_font(  CenterLabel->font() );
	CenterLabel_font.setPointSize( 11 );
	CenterLabel->setFont( CenterLabel_font ); 
	QFont CenterEdit_font(  data[ CenterEdit ]->font() );
	CenterEdit_font.setPointSize( 11 );
	data[ CenterEdit ]->setFont( CenterEdit_font ); 
	QFont RadiusLabel_font(  RadiusLabel->font() );
	RadiusLabel_font.setPointSize( 11 );
	RadiusLabel->setFont( RadiusLabel_font ); 
	QFont RadiusEdit_font(  data[ RadiusEdit ]->font() );
	RadiusEdit_font.setPointSize( 11 );
	data[ RadiusEdit ]->setFont( RadiusEdit_font ); 
	QFont DataForMethodsBox_font(  DataForMethodsBox->font() );
	DataForMethodsBox_font.setFamily( "adobe-helvetica" );
	DataForMethodsBox_font.setPointSize( 12 );
	DataForMethodsBox->setFont( DataForMethodsBox_font ); 
	QFont Test4Edit_font(  data[ Test4Edit ]->font() );
	Test4Edit_font.setPointSize( 11 );
	data[ Test4Edit ]->setFont( Test4Edit_font ); 
	QFont RelErrLabel_font(  RelErrLabel->font() );
	RelErrLabel_font.setPointSize( 11 );
	RelErrLabel->setFont( RelErrLabel_font ); 
	QFont MinNoSeg1Edit_font(  data[ MinNoSeg1Edit ]->font() );
	MinNoSeg1Edit_font.setPointSize( 11 );
	data[ MinNoSeg1Edit ]->setFont( MinNoSeg1Edit_font ); 
	QFont MaxNoSeg3Edit_font(  data[ MaxNoSeg3Edit ]->font() );
	MaxNoSeg3Edit_font.setPointSize( 11 );
	data[ MaxNoSeg3Edit ]->setFont( MaxNoSeg3Edit_font ); 
	QFont PrecisionLabel_font(  PrecisionLabel->font() );
	PrecisionLabel_font.setPointSize( 11 );
	PrecisionLabel->setFont( PrecisionLabel_font ); 
	QFont MaxOrderLabel_font(  MaxOrderLabel->font() );
	MaxOrderLabel_font.setPointSize( 11 );
	MaxOrderLabel->setFont( MaxOrderLabel_font ); 
	QFont RelErr4Edit_font(  data[ RelErr4Edit ]->font() );
	RelErr4Edit_font.setPointSize( 11 );
	data[ RelErr4Edit ]->setFont( RelErr4Edit_font ); 
	QFont OrderTaylMeth2Edit_font(  data[ OrderTaylMeth2Edit ]->font() );
	OrderTaylMeth2Edit_font.setPointSize( 11 );
	data[ OrderTaylMeth2Edit ]->setFont( OrderTaylMeth2Edit_font ); 
	QFont AbsErr4Edit_font(  data[ AbsErr4Edit ]->font() );
	AbsErr4Edit_font.setPointSize( 11 );
	data[ AbsErr4Edit ]->setFont( AbsErr4Edit_font ); 
	QFont MaxTime2Edit_font(  data[ MaxTime2Edit ]->font() );
	MaxTime2Edit_font.setPointSize( 11 );
	data[ MaxTime2Edit ]->setFont( MaxTime2Edit_font ); 
	QFont MaxOrd2Edit_font(  data[ MaxOrd2Edit ]->font() );
	MaxOrd2Edit_font.setPointSize( 11 );
	data[ MaxOrd2Edit ]->setFont( MaxOrd2Edit_font ); 
	QFont MaxCompTimeLabel_font(  MaxCompTimeLabel->font() );
	MaxCompTimeLabel_font.setPointSize( 11 );
	MaxCompTimeLabel->setFont( MaxCompTimeLabel_font ); 
	QFont RelErr1Edit_font(  data[ RelErr1Edit ]->font() );
	RelErr1Edit_font.setPointSize( 11 );
	data[ RelErr1Edit ]->setFont( RelErr1Edit_font ); 
	QFont PrecTayl2Edit_font(  data[ PrecTayl2Edit ]->font() );
	PrecTayl2Edit_font.setPointSize( 11 );
	data[ PrecTayl2Edit ]->setFont( PrecTayl2Edit_font ); 
	QFont OrdDeriv3Edit_font(  data[ OrdDeriv3Edit ]->font() );
	OrdDeriv3Edit_font.setPointSize( 11 );
	data[ OrdDeriv3Edit ]->setFont( OrdDeriv3Edit_font ); 
	QFont Test2Edit_font( data[ Test2Edit ]->font() );
	Test2Edit_font.setPointSize( 11 );
	data[ Test2Edit ]->setFont( Test2Edit_font ); 
	QFont Method3InputLabel_font( Method3InputLabel->font() );
	Method3InputLabel_font.setPointSize( 11 );
	Method3InputLabel->setFont( Method3InputLabel_font ); 
	QFont OrdDeriv4Edit_font( data[ OrdDeriv4Edit ]->font() );
	OrdDeriv4Edit_font.setPointSize( 11 );
	data[ OrdDeriv4Edit ]->setFont( OrdDeriv4Edit_font ); 
	QFont MaxNoSeg4Edit_font( data[ MaxNoSeg4Edit ]->font() );
	MaxNoSeg4Edit_font.setPointSize( 11 );
	data[ MaxNoSeg4Edit ]->setFont( MaxNoSeg4Edit_font ); 
	QFont MaxTime3Edit_font( data[ MaxTime3Edit ]->font() );
	MaxTime3Edit_font.setPointSize( 11 );
	data[ MaxTime3Edit ]->setFont( MaxTime3Edit_font ); 
   	QFont FixedSubdivCheckBox_font( FixedSubdivCheckBox->font() );
	FixedSubdivCheckBox_font.setPointSize( 11 );
	FixedSubdivCheckBox->setFont( FixedSubdivCheckBox_font ); 
   	QFont OptimizationCheckBox_font( OptimizationCheckBox->font() );
	OptimizationCheckBox_font.setPointSize( 11 );
	OptimizationCheckBox->setFont( OptimizationCheckBox_font ); 
	QFont MinNoSeg4Edit_font( data[ MinNoSeg4Edit ]->font() );
	MinNoSeg4Edit_font.setPointSize( 11 );
	data[ MinNoSeg4Edit ]->setFont( MinNoSeg4Edit_font ); 
	QFont AbsErr3Edit_font( data[ AbsErr3Edit ]->font() );
	AbsErr3Edit_font.setPointSize( 11 );
	data[ AbsErr3Edit ]->setFont( AbsErr3Edit_font ); 
	QFont AbsErrLabel_font( AbsErrLabel->font() );
	AbsErrLabel_font.setPointSize( 11 );
	AbsErrLabel->setFont( AbsErrLabel_font ); 
	QFont PrecTayl4Edit_font( data[ PrecTayl4Edit ]->font() );
	PrecTayl4Edit_font.setPointSize( 11 );
	data[ PrecTayl4Edit ]->setFont( PrecTayl4Edit_font ); 
	QFont TestLabel_font(  TestLabel->font() );
	TestLabel_font.setPointSize( 11 );
	TestLabel->setFont( TestLabel_font ); 
	QFont OrderTaylMeth4Edit_font(  data[ OrderTaylMeth4Edit ]->font() );
	OrderTaylMeth4Edit_font.setPointSize( 11 );
	data[ OrderTaylMeth4Edit ]->setFont( OrderTaylMeth4Edit_font ); 
	QFont MaxOrd4Edit_font(  data[ MaxOrd4Edit ]->font() );
	MaxOrd4Edit_font.setPointSize( 11 );
	data[ MaxOrd4Edit ]->setFont( MaxOrd4Edit_font ); 
	QFont MaxTime1Edit_font(  data[ MaxTime1Edit ]->font() );
	MaxTime1Edit_font.setPointSize( 11 );
	data[ MaxTime1Edit ]->setFont( MaxTime1Edit_font ); 
	QFont Method1InputLabel_font(  Method1InputLabel->font() );
	Method1InputLabel_font.setPointSize( 11 );
	Method1InputLabel->setFont( Method1InputLabel_font ); 
	QFont OrderLabel_font(  OrderLabel->font() );
	OrderLabel_font.setPointSize( 11 );
	OrderLabel->setFont( OrderLabel_font ); 
	QFont RelErr3Edit_font(  data[ RelErr3Edit ]->font() );
	RelErr3Edit_font.setPointSize( 11 );
	data[ RelErr3Edit ]->setFont( RelErr3Edit_font ); 
	QFont MinNoSeg3Edit_font(  data[ MinNoSeg3Edit ]->font() );
	MinNoSeg3Edit_font.setPointSize( 11 );
	data[ MinNoSeg3Edit ]->setFont( MinNoSeg3Edit_font ); 
	QFont Method4InputLabel_font(  Method4InputLabel->font() );
	Method4InputLabel_font.setPointSize( 11 );
	Method4InputLabel->setFont( Method4InputLabel_font ); 
	QFont AbsErr2Edit_font(  data[ AbsErr2Edit ]->font() );
	AbsErr2Edit_font.setPointSize( 11 );
	data[ AbsErr2Edit ]->setFont( AbsErr2Edit_font ); 
	QFont MaxNoSeg1Edit_font(  data[ MaxNoSeg1Edit ]->font() );
	MaxNoSeg1Edit_font.setPointSize( 11 );
	data[ MaxNoSeg1Edit ]->setFont( MaxNoSeg1Edit_font ); 
	QFont MaxTime4Edit_font(  data[ MaxTime4Edit ]->font() );
	MaxTime4Edit_font.setPointSize( 11 );
	data[ MaxTime4Edit ]->setFont( MaxTime4Edit_font ); 
	QFont AbsErr1Edit_font(  data[ AbsErr1Edit ]->font() );
	AbsErr1Edit_font.setPointSize( 11 );
	data[ AbsErr1Edit ]->setFont( AbsErr1Edit_font ); 
	QFont Method2InputLabel_font(  Method2InputLabel->font() );
	Method2InputLabel_font.setPointSize( 11 );
	Method2InputLabel->setFont( Method2InputLabel_font ); 
	QFont DerivativeLabel_font(  DerivativeLabel->font() );
	DerivativeLabel_font.setPointSize( 11 );
	DerivativeLabel->setFont( DerivativeLabel_font ); 
	QFont RelErr2Edit_font(  data[ RelErr2Edit ]->font() );
	RelErr2Edit_font.setPointSize( 11 );
	data[ RelErr2Edit ]->setFont( RelErr2Edit_font ); 
	QFont MinNoSegLabel_font(  MinNoSegLabel->font() );
	MinNoSegLabel_font.setPointSize( 11 );
	MinNoSegLabel->setFont( MinNoSegLabel_font ); 
	QFont MinNoSeg2Edit_font(  data[ MinNoSeg2Edit ]->font() );
	MinNoSeg2Edit_font.setPointSize( 11 );
	data[ MinNoSeg2Edit ]->setFont( MinNoSeg2Edit_font ); 
	QFont MaxNoSeg2Edit_font(  data[ MaxNoSeg2Edit ]->font() );
	MaxNoSeg2Edit_font.setPointSize( 11 );
	data[ MaxNoSeg2Edit ]->setFont( MaxNoSeg2Edit_font ); 
	QFont MaxNoSegLabel_font(  MaxNoSegLabel->font() );
	MaxNoSegLabel_font.setPointSize( 11 );
	MaxNoSegLabel->setFont( MaxNoSegLabel_font ); 
	QFont BoundsBox_font(  BoundsBox->font() );
	BoundsBox_font.setFamily( "adobe-helvetica" );
	BoundsBox_font.setPointSize( 12 );
	BoundsBox->setFont( BoundsBox_font ); 
	QFont Bounds_ListBox_font(  Bounds_ListBox->font() );
	Bounds_ListBox_font.setPointSize( 11 );
	Bounds_ListBox->setFont( Bounds_ListBox_font ); 
	QFont RemaindersBox_font(  RemaindersBox->font() );
	RemaindersBox_font.setFamily( "adobe-helvetica" );
	RemaindersBox_font.setPointSize( 12 );
	RemaindersBox->setFont( RemaindersBox_font ); 
	QFont Remainders_ListBox_font(  Remainders_ListBox->font() );
	Remainders_ListBox_font.setPointSize( 11 );
	Remainders_ListBox->setFont( Remainders_ListBox_font ); 
	QFont OmegaBox_font(  OmegaBox->font() );
	OmegaBox_font.setFamily( "adobe-helvetica" );
	OmegaBox_font.setPointSize( 12 );
	OmegaBox->setFont( OmegaBox_font ); 
	QFont Omega_ListBox_font(  Omega_ListBox->font() );
	Omega_ListBox_font.setPointSize( 11 );
	Omega_ListBox->setFont( Omega_ListBox_font ); 
    }
    return ret;
}

bool InputWidget::CheckBoxValue(int i) const
{
  switch( i )
    {
    case 1:
      {
	return M1;
      }
    case 2:
      {
	return M2;
      }
    case 3:
      {
	return M3;
      }
    case 4:
      {
	return M4;
      }
    case 5:
      {
	return fixedsubdiv;
      }
    case 6:
      {
	return optimization;
      }
    }
}

void InputWidget::setCheckBoxValue(int i, bool f)
{
  switch( i )
    {
    case 1:
      {
	Method1_CheckBox->setChecked( f );
	break;
      }
    case 2:
      {
	Method2_CheckBox->setChecked( f );
	break;
      }
    case 3:
      {
	Method3_CheckBox->setChecked( f );
	break;
      }
    case 4:
      {
	Method4_CheckBox->setChecked( f );
	break;
      }
    case 5:
      {
	FixedSubdivCheckBox->setChecked( f );
	break;
      }
    case 6:
      {
	OptimizationCheckBox->setChecked( f );
	break;
      }
    }
}

void InputWidget::CheckBoxToggled()
{
  const QObject *box = sender();
  
  if( box == Method1_CheckBox ) 
    {
      M1 = !M1;
      activateM( 1 );
      return;
    }
  if( box == Method2_CheckBox ) 
    {
      M2 = !M2;
      activateM( 2 );
      return;
    }
  if( box == Method3_CheckBox ) 
    {
      M3 = !M3;
      activateM( 3 );
      return;
    }
  if( box == Method4_CheckBox ) 
    {
      M4 = !M4;
      activateM( 4 );
      return;
    }
  if( box == Verbose_CheckBox )
    {
      verbose = !verbose;
      return;
    }
  if( box == FixedSubdivCheckBox )
    {
      fixedsubdiv = !fixedsubdiv; 
      OptimizationCheckBox->setEnabled( ( M2 || M4 ) && fixedsubdiv );
      data[ Test2Edit   ]->setEnabled( M2 && fixedsubdiv && optimization );
      data[ MaxOrd2Edit ]->setEnabled( M2 && fixedsubdiv && optimization );
      data[ Test4Edit   ]->setEnabled( M4 && fixedsubdiv && optimization );
      data[ MaxOrd4Edit ]->setEnabled( M4 && fixedsubdiv && optimization );
      return;
    }
  if( box == OptimizationCheckBox )
    {
      optimization = !optimization;
      data[ Test2Edit   ]->setEnabled( M2 && fixedsubdiv && optimization );
      data[ MaxOrd2Edit ]->setEnabled( M2 && fixedsubdiv && optimization );
      data[ Test4Edit   ]->setEnabled( M4 && fixedsubdiv && optimization );
      data[ MaxOrd4Edit ]->setEnabled( M4 && fixedsubdiv && optimization );
      return;
    }
}

void InputWidget::InputEnable(bool on)
{
  if( on )
    {
      data[ ExprEdit   ]->setEnabled( on ); 
      data[ CenterEdit ]->setEnabled( on );
      data[ RadiusEdit ]->setEnabled( on );
 
      activateM( 1 );
      activateM( 2 );
      activateM( 3 );
      activateM( 4 );

      Method1_CheckBox->setEnabled( true );
      Method2_CheckBox->setEnabled( true ); 
      Method3_CheckBox->setEnabled( true ); 
      Method4_CheckBox->setEnabled( true ); 
      Verbose_CheckBox->setEnabled( true ); 
      
      Bounds_ListBox->setEnabled( true );
      Remainders_ListBox->setEnabled( true );
      Omega_ListBox->setEnabled( true );
    }
  else
    {
      disableAll();
    }
}

void InputWidget::activateM(int i)
{
  switch( i )
    {
    case 1:
      {
	data[ MaxNoSeg1Edit ]->setEnabled( M1 );
	data[ MinNoSeg1Edit ]->setEnabled( M1 );
	data[ RelErr1Edit   ]->setEnabled( M1 );
	data[ AbsErr1Edit   ]->setEnabled( M1 );
	data[ MaxTime1Edit  ]->setEnabled( M1 );
	break;
      }
    case 2:
      {
	data[ OrderTaylMeth2Edit ]->setEnabled( M2 );
	//data[ PrecTayl2Edit      ]->setEnabled( M2 );
	data[ Test2Edit          ]->setEnabled( M2 && fixedsubdiv && optimization );
	data[ MaxOrd2Edit        ]->setEnabled( M2 && fixedsubdiv && optimization );
	data[ MaxNoSeg2Edit      ]->setEnabled( M2 );
	data[ MinNoSeg2Edit      ]->setEnabled( M2 );
	data[ AbsErr2Edit        ]->setEnabled( M2 );
	data[ RelErr2Edit        ]->setEnabled( M2 );
	data[ MaxTime2Edit       ]->setEnabled( M2 );
	FixedSubdivCheckBox->setEnabled( M2 || M4 );
	OptimizationCheckBox->setEnabled( ( M2 || M4 ) && fixedsubdiv );
	break;
      }
    case 3:
      {
	data[ OrdDeriv3Edit ]->setEnabled( M3 );
	data[ MaxNoSeg3Edit ]->setEnabled( M3 );
	data[ MinNoSeg3Edit ]->setEnabled( M3 );
	data[ RelErr3Edit   ]->setEnabled( M3 );
	data[ AbsErr3Edit   ]->setEnabled( M3 );
	data[ MaxTime3Edit  ]->setEnabled( M3 );
	break;
      }
    case 4:
      {
	data[ OrderTaylMeth4Edit ]->setEnabled( M4 );
	//data[ PrecTayl4Edit      ]->setEnabled( M4 );
	data[ OrdDeriv4Edit      ]->setEnabled( M4 );
	data[ Test4Edit          ]->setEnabled( M4 && fixedsubdiv && optimization );
	data[ MaxOrd4Edit        ]->setEnabled( M4 && fixedsubdiv && optimization );
	data[ MaxNoSeg4Edit      ]->setEnabled( M4 );
	data[ MinNoSeg4Edit      ]->setEnabled( M4 );
	data[ RelErr4Edit        ]->setEnabled( M4 );
	data[ AbsErr4Edit        ]->setEnabled( M4 );
	data[ MaxTime4Edit       ]->setEnabled( M4 );
	FixedSubdivCheckBox->setEnabled( M2 || M4 );
	OptimizationCheckBox->setEnabled( ( M2 || M4 ) && fixedsubdiv );
	break;
      }
    }
}

void InputWidget::disableAll()
{
  for(int i=0; i<33; i++) data[i]->setEnabled( false );
  
  Method1_CheckBox->setEnabled( false );
  Method2_CheckBox->setEnabled( false ); 
  Method3_CheckBox->setEnabled( false ); 
  Method4_CheckBox->setEnabled( false ); 
  Verbose_CheckBox->setEnabled( false ); 
  FixedSubdivCheckBox->setEnabled( false );
  OptimizationCheckBox->setEnabled( false );

  Bounds_ListBox->setEnabled( false );
  Remainders_ListBox->setEnabled( false );
  Omega_ListBox->setEnabled( false );
}

#include "gui_inputwidget.moc"

/*

  End of File: gui_inputwidget.cpp

*/

