/*

 File: gui_taylorcoeffdialog.cpp, 2003/06/17

 ACETAF, Version 3.0.0

 Copyright (C) Markus Neher, markus.neher@math.uni-karlsruhe.de
               Ingo Eble,    ingoeble@web.de

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#include "gui_taylorcoeffdialog.h"

#include <qstring.h>
#include <qmessagebox.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qvariant.h>
#include <qtooltip.h>
#include <qwhatsthis.h>

#include "stringutil.h"


/* 
 *  Constructs a TaylorCoeffDialog which is a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f' 
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */

const QString dialogName( "Calculate taylor coefficients" );

TaylorCoeffDialog::TaylorCoeffDialog( QWidget* parent,  const char* name, bool modal, WFlags fl)
    : QDialog( parent, name, modal, fl )
{
    if ( !name )
	setName( "TaylorCoeffDialog" );
    resize( 290, 120 ); 
    setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, sizePolicy().hasHeightForWidth() ) );
    setMinimumSize( QSize( 290, 120 ) );
    setMaximumSize( QSize( 290, 120 ) );
    setCaption( tr( dialogName ) );
    TaylorCoeffDialogLayout = new QVBoxLayout( this ); 
    TaylorCoeffDialogLayout->setSpacing( 6 );
    TaylorCoeffDialogLayout->setMargin( 11 );

    Layout11 = new QHBoxLayout; 
    Layout11->setSpacing( 6 );
    Layout11->setMargin( 0 );

    Layout5 = new QVBoxLayout; 
    Layout5->setSpacing( 6 );
    Layout5->setMargin( 0 );

    Label_DevelPoint = new QLabel( this, "Label_DevelPoint" );
    Label_DevelPoint->setText( tr( "Development point =" ) );
    Label_DevelPoint->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );
    Layout5->addWidget( Label_DevelPoint );

    Label_NumberCoeff = new QLabel( this, "Label_NumberCoeff" );
    Label_NumberCoeff->setText( tr( "Taylor coefficients up to order:" ) );
    Layout5->addWidget( Label_NumberCoeff );
    Layout11->addLayout( Layout5 );

    Layout9 = new QVBoxLayout; 
    Layout9->setSpacing( 6 );
    Layout9->setMargin( 0 );

    EditDevelPoint = new QLineEdit( this, "EditDevelPoint" );
    Layout9->addWidget( EditDevelPoint );

    EditNumberCoeff = new QLineEdit( this, "EditNumberCoeff" );
    Layout9->addWidget( EditNumberCoeff );
    Layout11->addLayout( Layout9 );
    TaylorCoeffDialogLayout->addLayout( Layout11 );

    Layout8 = new QHBoxLayout; 
    Layout8->setSpacing( 6 );
    Layout8->setMargin( 0 );
    QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    Layout8->addItem( spacer );

    Layout7 = new QHBoxLayout; 
    Layout7->setSpacing( 6 );
    Layout7->setMargin( 0 );

    OKButton = new QPushButton( this, "OKButton" );
    OKButton->setText( tr( "OK" ) );
    Layout7->addWidget( OKButton );
    QSpacerItem* spacer_2 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    Layout7->addItem( spacer_2 );

    CancelButton = new QPushButton( this, "CancelButton" );
    CancelButton->setText( tr( "Cancel" ) );
    Layout7->addWidget( CancelButton );
    Layout8->addLayout( Layout7 );
    TaylorCoeffDialogLayout->addLayout( Layout8 );

    QToolTip::add( EditDevelPoint,  "Complex point: Re,Im"); 
    QToolTip::add( EditNumberCoeff, "Must be lower than 150"); 

    // signals and slots connections
    connect( OKButton, SIGNAL( clicked() ), this, SLOT( OKButtonPressed() ) );
    connect( OKButton, SIGNAL( clicked() ), this, SLOT( accept() ) );
    connect( CancelButton, SIGNAL( clicked() ), this, SLOT( reject() ) );
}

/*  
 *  Destroys the object and frees any allocated resources
 */
TaylorCoeffDialog::~TaylorCoeffDialog()
{
    // no need to delete child widgets, Qt does it all for us
}

void TaylorCoeffDialog::OKButtonPressed()
{
  QString devp( EditDevelPoint ->text() );
  QString numc( EditNumberCoeff->text() );

  if( devp.isEmpty() )
    QMessageBox::information( this, dialogName, "Input not complete! Try again.");
  else if( numc.isEmpty() )
    QMessageBox::information( this, dialogName, "Input not complete! Try again.");
  else
    {
      Complex c;
      devp >> c;

      int n = atoi( numc.latin1() );
      if( n < 0 )     
	{
	  QMessageBox::information( this, dialogName, "Nothing to do.");
	  return;
	}
      emit sendData( c, n );
    }
}

#include "gui_taylorcoeffdialog.moc"

/*

  End of File: gui_taylorcoeffdialog.cpp

*/
