/*
  
  File: optim.h, 2003/06/17
  
  ACETAF, Version 3.0.0
  
  Copyright (C) Markus Neher, markus.neher@math.uni-karlsruhe.de
                Ingo Eble,    ingoeble@web.de
  
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#ifndef _OPTIM_H_INCLUDED
#define _OPTIM_H_INCLUDED

#include <qthread.h>
#include <qobject.h>

#include "methodbase.h"
#include "stopwatch.h"
#include "shareddata.h"
#include "adaptintval.h"

#include <map>

using Adapt::Interval;

struct OptimData
{
  MethodBase *mth;
  unsigned int maxSegments;
  unsigned int minSegments;
  double relPrec;
  double absPrec;
  double maxTime;

  OptimData(MethodBase *mb, 
	    unsigned int maS, 
	    unsigned int miS, 
	    const double& r, 
	    const double& a, 
	    const double& mT) : mth( mb ),
                                maxSegments( maS ),
                                minSegments( miS ),
                                relPrec( r ),
                                absPrec( a ),
                                maxTime( mT )
  {}
};

enum OptimError { 
  NO_ERROR   = 0,
  PREC_ERROR = 1
};

struct OptimResult
{
  OptimError err;
  Interval   max;
  double     relprec;
  double     absprec;
  double     subtlety;
  double     calctime;
  int        segments_sum;
  int        candidates;
  int        PolyordMth2;
  int        PolyordMth4;
};

class OptimAlgBase : public QThread, public QObject
{
 public:

  OptimAlgBase(OptimData *d, OptimResult *r, bool g, bool& res, SharedData *s) : garbageflag     ( g   ),
                                                                                 result_available( res ),
                                                                                 odat            ( d   ),
                                                                                 ores            ( r   ),
                                                                                 shd             ( s   )
    {
      result_available = false;
    }
  ~OptimAlgBase() {}
  
 protected:

  stopwatch CPU_Time;
  bool garbageflag;
  bool& result_available;

  OptimData   *odat;
  OptimResult *ores;
  SharedData  *shd;
};

class OptimAlgA : public OptimAlgBase
{
 public:

  OptimAlgA(OptimData *d, OptimResult *r, bool g, bool& res, SharedData *s) : OptimAlgBase( d, r, g, res, s ),
                                                                              infMax(0.0),
                                                                              supMax(0.0)
    {}
  ~OptimAlgA() {}

 protected:
  
  void timerEvent(QTimerEvent * );
  void run();
  void collect_results();

 private:

  double infMax, supMax;
  std::multimap<double,Interval,std::greater<double> > ListOfCandidates;//Key = double, Value = interval
};

class OptimAlgB : public OptimAlgBase
{
 public:

  OptimAlgB(OptimData *d, OptimResult *r, bool g, bool& res, SharedData *s) : OptimAlgBase( d, r, g, res, s ), 
                                                                              infMax(0.0),
                                                                              supMax(0.0)
    {}
  ~OptimAlgB() {}

 protected:

  void timerEvent(QTimerEvent * );
  void run();
  void collect_results();

 private:

  double infMax, supMax;
};

#endif

/*

  End of File: optim.h

*/
